@@ -16,29 +16,29 @@
 #    PARTICULAR. Consulte a Licenca Publica Geral GNU para obter mais
 #    detalhes.
 #--------------------------------------------------------------------------
-import math
 import os
 import plistlib
 import wx
-import numpy
 from wx.lib.pubsub import pub as Publisher
 
-import constants as const
-import data.imagedata_utils as image_utils
-import data.mask as msk
-import data.measures
-import data.slice_ as sl
-import data.surface as srf
-import data.volume as volume
-import gui.dialogs as dialog
-import project as prj
-import reader.analyze_reader as analyze
-import reader.dicom_grouper as dg
-import reader.dicom_reader as dcm
-import session as ses
+import invesalius.constants as const
+import invesalius.data.imagedata_utils as image_utils
+import invesalius.data.mask as msk
+import invesalius.data.measures as measures
+import invesalius.data.slice_ as sl
+import invesalius.data.surface as srf
+import invesalius.data.volume as volume
+import invesalius.gui.dialogs as dialog
+import invesalius.project as prj
+import invesalius.reader.dicom_grouper as dg
+import invesalius.reader.dicom_reader as dcm
+import invesalius.reader.bitmap_reader as bmp
+import invesalius.reader.others_reader as oth
+import invesalius.session as ses
 
-import utils 
-import gui.dialogs as dialogs
+
+import invesalius.utils  as utils
+import invesalius.gui.dialogs as dialogs
 import subprocess
 import sys
 
@@ -53,9 +53,16 @@ class Controller():
         self.frame = frame
         self.progress_dialog = None
         self.cancel_import = False
+
+        #type of imported image
+        #None, others and opened Project = 0
+        #DICOM = 1
+        #TIFF uCT = 2
+        self.img_type = 0 
+
         #Init session
         session = ses.Session()
-        self.measure_manager = data.measures.MeasurementManager()
+        self.measure_manager = measures.MeasurementManager()
 
         Publisher.sendMessage('Load Preferences')
 
@@ -63,6 +70,8 @@ class Controller():
         Publisher.subscribe(self.OnImportMedicalImages, 'Import directory')
         Publisher.subscribe(self.OnShowDialogImportDirectory,
                                  'Show import directory dialog')
+        Publisher.subscribe(self.OnShowDialogImportOtherFiles,
+                                 'Show import other files dialog')
         Publisher.subscribe(self.OnShowDialogOpenProject,
                                  'Show open project dialog')
 
@@ -74,23 +83,40 @@ class Controller():
                                  'Save raycasting preset')
         Publisher.subscribe(self.OnOpenDicomGroup,
                                  'Open DICOM group')
+        Publisher.subscribe(self.OnOpenBitmapFiles,
+                                 'Open bitmap files')
+        Publisher.subscribe(self.OnOpenOtherFiles,
+                                 'Open other files')
         Publisher.subscribe(self.Progress, "Update dicom load")
+        Publisher.subscribe(self.Progress, "Update bitmap load")
         Publisher.subscribe(self.OnLoadImportPanel, "End dicom load")
+        Publisher.subscribe(self.OnLoadImportBitmapPanel, "End bitmap load")
         Publisher.subscribe(self.OnCancelImport, 'Cancel DICOM load')
+        Publisher.subscribe(self.OnCancelImportBitmap, 'Cancel bitmap load')
+
         Publisher.subscribe(self.OnShowDialogCloseProject, 'Close Project')
         Publisher.subscribe(self.OnOpenProject, 'Open project')
         Publisher.subscribe(self.OnOpenRecentProject, 'Open recent project')
-        Publisher.subscribe(self.OnShowAnalyzeFile, 'Show analyze dialog')
+        Publisher.subscribe(self.OnShowBitmapFile, 'Show bitmap dialog')
 
         Publisher.subscribe(self.ShowBooleanOpDialog, 'Show boolean dialog')
 
+        Publisher.subscribe(self.ApplyReorientation, 'Apply reorientation')
+
+        Publisher.subscribe(self.SetBitmapSpacing, 'Set bitmap spacing')
+
+    def SetBitmapSpacing(self, pubsub_evt):
+        proj = prj.Project()
+        proj.spacing = pubsub_evt.data
 
     def OnCancelImport(self, pubsub_evt):
         #self.cancel_import = True
         Publisher.sendMessage('Hide import panel')
 
 
-
+    def OnCancelImportBitmap(self, pubsub_evt):
+        #self.cancel_import = True
+        Publisher.sendMessage('Hide import bitmap panel')
 
 ###########################
 ###########################
@@ -98,6 +124,10 @@ class Controller():
     def OnShowDialogImportDirectory(self, pubsub_evt):
         self.ShowDialogImportDirectory()
 
+    def OnShowDialogImportOtherFiles(self, pubsub_evt):
+        id_type = pubsub_evt.data
+        self.ShowDialogImportOtherFiles(id_type)
+
     def OnShowDialogOpenProject(self, pubsub_evt):
         self.ShowDialogOpenProject()
 
@@ -108,18 +138,34 @@ class Controller():
     def OnShowDialogCloseProject(self, pubsub_evt):
         self.ShowDialogCloseProject()
 
-    def OnShowAnalyzeFile(self, pubsub_evt):
-        dirpath = dialog.ShowOpenAnalyzeDialog()
-        imagedata = analyze.ReadAnalyze(dirpath)
-        if imagedata:
-            self.CreateAnalyzeProject(imagedata)
-            
-        self.LoadProject()
-        Publisher.sendMessage("Enable state project", True)
-
-
+    def OnShowBitmapFile(self, pubsub_evt):
+        self.ShowDialogImportBitmapFile()
 ###########################
 
+    def ShowDialogImportBitmapFile(self):
+        # Offer to save current project if necessary
+        session = ses.Session()
+        st = session.project_status
+        if (st == const.PROJ_NEW) or (st == const.PROJ_CHANGE):
+            filename = session.project_path[1]
+            answer = dialog.SaveChangesDialog2(filename)
+            if answer:
+                self.ShowDialogSaveProject()
+            self.CloseProject()
+            #Publisher.sendMessage("Enable state project", False)
+            Publisher.sendMessage('Set project name')
+            Publisher.sendMessage("Stop Config Recording")
+            Publisher.sendMessage("Set slice interaction style", const.STATE_DEFAULT)
+
+        # Import TIFF, BMP, JPEG or PNG
+        dirpath = dialog.ShowImportBitmapDirDialog(self.frame)
+
+        if dirpath and not os.listdir(dirpath):
+            dialog.ImportEmptyDirectory(dirpath)
+        elif dirpath:
+            self.StartImportBitmapPanel(dirpath)
+        #    Publisher.sendMessage("Load data to import panel", dirpath)
+
     def ShowDialogImportDirectory(self):
         # Offer to save current project if necessary
         session = ses.Session()
@@ -135,13 +181,35 @@ class Controller():
             Publisher.sendMessage("Stop Config Recording")
             Publisher.sendMessage("Set slice interaction style", const.STATE_DEFAULT)
         # Import project
-        dirpath = dialog.ShowImportDirDialog()
+        dirpath = dialog.ShowImportDirDialog(self.frame)
         if dirpath and not os.listdir(dirpath):
             dialog.ImportEmptyDirectory(dirpath)
         elif dirpath:
             self.StartImportPanel(dirpath)
             Publisher.sendMessage("Load data to import panel", dirpath)
 
+    def ShowDialogImportOtherFiles(self, id_type):
+        # Offer to save current project if necessary
+        session = ses.Session()
+        st = session.project_status
+        if (st == const.PROJ_NEW) or (st == const.PROJ_CHANGE):
+            filename = session.project_path[1]
+            answer = dialog.SaveChangesDialog2(filename)
+            if answer:
+                self.ShowDialogSaveProject()
+            self.CloseProject()
+            # Publisher.sendMessage("Enable state project", False)
+            Publisher.sendMessage('Set project name')
+            Publisher.sendMessage("Stop Config Recording")
+            Publisher.sendMessage("Set slice interaction style", const.STATE_DEFAULT)
+
+        # Warning for limited support to Analyze format
+        if id_type == const.ID_ANALYZE_IMPORT:
+            dialog.ImportAnalyzeWarning()
+
+        filepath = dialog.ShowImportOtherFilesDialog(id_type)
+        Publisher.sendMessage("Open other files", filepath)
+
     def ShowDialogOpenProject(self):
         # Offer to save current project if necessary
         session = ses.Session()
@@ -237,8 +305,6 @@ class Controller():
         else:
             dialog.InexistentPath(filepath)
 
-
-
     def OpenProject(self, filepath):
         Publisher.sendMessage('Begin busy cursor')
         path = os.path.abspath(filepath)
@@ -272,6 +338,9 @@ class Controller():
         else:
             dirpath, filename = session.project_path
 
+        if isinstance(filename, str):
+            filename = filename.decode(const.FS_ENCODE)
+
         proj = prj.Project()
         prj.Project().SavePlistProject(dirpath, filename)
 
@@ -279,20 +348,35 @@ class Controller():
         Publisher.sendMessage('End busy cursor')
 
     def CloseProject(self):
+        Publisher.sendMessage('Set slice interaction style', const.STATE_DEFAULT)
+        Publisher.sendMessage('Hide content panel')
+        Publisher.sendMessage('Close project data')
+
+        if self.img_type == 1:
+            Publisher.sendMessage('Show import panel in frame')
+
+        if self.img_type == 2:
+            Publisher.sendMessage('Show import bitmap panel in frame')
+
+
         proj = prj.Project()
         proj.Close()
 
-        Publisher.sendMessage('Hide content panel')
-        Publisher.sendMessage('Close project data')
         session = ses.Session()
         session.CloseProject()
 
 ###########################
 
+    def StartImportBitmapPanel(self, path):
+        # retrieve DICOM files splited into groups
+        reader = bmp.ProgressBitmapReader()
+        reader.SetWindowEvent(self.frame)
+        reader.SetDirectoryPath(path)
+        Publisher.sendMessage('End busy cursor')
 
     def StartImportPanel(self, path):
 
-        # retrieve DICOM files splited into groups
+        # retrieve DICOM files split into groups
         reader = dcm.ProgressDicomReader()
         reader.SetWindowEvent(self.frame)
         reader.SetDirectoryPath(path)
@@ -321,6 +405,27 @@ class Controller():
         if ok:
             Publisher.sendMessage('Show import panel')
             Publisher.sendMessage("Show import panel in frame")
+            self.img_type = 1
+
+    def OnLoadImportBitmapPanel(self, evt):
+        data = evt.data
+        ok = self.LoadImportBitmapPanel(data)
+        if ok:
+            Publisher.sendMessage('Show import bitmap panel in frame')            
+            self.img_type = 2
+            #Publisher.sendMessage("Show import panel in invesalius.gui.frame") as frame
+
+    def LoadImportBitmapPanel(self, data):
+        #if patient_series and isinstance(patient_series, list):
+            #Publisher.sendMessage("Load import panel", patient_series)
+            #first_patient = patient_series[0]
+            #Publisher.sendMessage("Load bitmap preview", first_patient)
+        if  data:
+            Publisher.sendMessage("Load import bitmap panel", data)
+            return True
+        else:
+            dialog.ImportInvalidFiles("Bitmap")
+        return False
 
 
     def LoadImportPanel(self, patient_series):
@@ -330,37 +435,55 @@ class Controller():
             Publisher.sendMessage("Load dicom preview", first_patient)
             return True
         else:
-            dialog.ImportInvalidFiles()
+            dialog.ImportInvalidFiles("DICOM")
         return False
 
+
+    #----------- to import by command line ---------------------------------------------------
+
     def OnImportMedicalImages(self, pubsub_evt):
         directory = pubsub_evt.data
         self.ImportMedicalImages(directory)
 
     def ImportMedicalImages(self, directory):
-        # OPTION 1: DICOM?
         patients_groups = dcm.GetDicomGroups(directory)
+        name = directory.rpartition('\\')[-1].split('.')
+        print "patients: ", patients_groups
+
         if len(patients_groups):
+            # OPTION 1: DICOM
             group = dcm.SelectLargerDicomGroup(patients_groups)
-            matrix, matrix_filename, dicom = self.OpenDicomGroup(group, 0, [0,0],gui=True)
+            matrix, matrix_filename, dicom = self.OpenDicomGroup(group, 0, [0, 0], gui=True)
             self.CreateDicomProject(dicom, matrix, matrix_filename)
-        # OPTION 2: ANALYZE?
         else:
-            imagedata = analyze.ReadDirectory(directory)
-            if imagedata:
-                self.CreateAnalyzeProject(imagedata)
-            # OPTION 3: Nothing...
+            # OPTION 2: NIfTI, Analyze or PAR/REC
+            if name[-1] == 'gz':
+                name[1] = 'nii.gz'
+
+            suptype = ('hdr', 'nii', 'nii.gz', 'par')
+            filetype = name[1].lower()
+
+            if filetype in suptype:
+                group = oth.ReadOthers(directory)
             else:
                 utils.debug("No medical images found on given directory")
                 return
+
+            matrix, matrix_filename = self.OpenOtherFiles(group)
+            self.CreateOtherProject(str(name[0]), matrix, matrix_filename)
+            # OPTION 4: Nothing...
+
         self.LoadProject()
         Publisher.sendMessage("Enable state project", True)
 
+    #-------------------------------------------------------------------------------------
+
     def LoadProject(self):
         proj = prj.Project()
         
         const.THRESHOLD_OUTVALUE = proj.threshold_range[0]
         const.THRESHOLD_INVALUE = proj.threshold_range[1]
+        const.THRESHOLD_RANGE = proj.threshold_modes[_("Bone")]
 
         const.WINDOW_LEVEL[_('Default')] = (proj.window, proj.level)
         const.WINDOW_LEVEL[_('Manual')] = (proj.window, proj.level)
@@ -395,13 +518,19 @@ class Controller():
                 Publisher.sendMessage('Add mask',
                                            (m.index, m.name,
                                             m.threshold_range, m.colour))
-            self.Slice.current_mask = proj.mask_dict[mask_index]
-            Publisher.sendMessage('Show mask', (mask_index, True))
+                if m.is_shown:
+                    self.Slice.current_mask = proj.mask_dict[mask_index]
+                    Publisher.sendMessage('Show mask', (m.index, True))
+                    Publisher.sendMessage('Change mask selected', m.index)
         else:
             mask_name = const.MASK_NAME_PATTERN % (1,)
-            thresh = const.THRESHOLD_RANGE
-            colour = const.MASK_COLOUR[0]
 
+            if proj.modality != "UNKNOWN":
+                thresh = const.THRESHOLD_RANGE
+            else:
+                thresh = proj.threshold_range
+
+            colour = const.MASK_COLOUR[0]
             Publisher.sendMessage('Create new mask',
                                        (mask_name, thresh, colour))
 
@@ -414,43 +543,6 @@ class Controller():
         
         Publisher.sendMessage('End busy cursor')
 
-    def CreateAnalyzeProject(self, imagedata):
-        header = imagedata.get_header()
-        proj = prj.Project()
-        proj.imagedata = None
-        proj.name = _("Untitled")
-        proj.SetAcquisitionModality("MRI")
-        #TODO: Verify if all Analyse are in AXIAL orientation
-
-        # To get  Z, X, Y (used by InVesaliu), not X, Y, Z
-        matrix, matrix_filename = image_utils.analyze2mmap(imagedata)
-        if header['orient'] == 0:
-            proj.original_orientation =  const.AXIAL
-        elif header['orient'] == 1:
-            proj.original_orientation = const.CORONAL
-        elif header['orient'] == 2:
-            proj.original_orientation = const.SAGITAL
-        else:
-            proj.original_orientation =  const.SAGITAL
-
-        proj.threshold_range = (int(header['glmin']),
-                                int(header['glmax']))
-        proj.window = proj.threshold_range[1] - proj.threshold_range[0]
-        proj.level =  (0.5 * (proj.threshold_range[1] + proj.threshold_range[0]))
-        proj.spacing = header['pixdim'][1:4]
-        proj.matrix_shape = matrix.shape 
-
-        self.Slice = sl.Slice()
-        self.Slice.matrix = matrix
-        self.Slice.matrix_filename = matrix_filename
-
-        self.Slice.window_level = proj.level
-        self.Slice.window_width = proj.window
-        self.Slice.spacing = header.get_zooms()[:3]
-
-        Publisher.sendMessage('Update threshold limits list',
-                                   proj.threshold_range)
-
     def CreateDicomProject(self, dicom, matrix, matrix_filename):
         name_to_const = {"AXIAL":const.AXIAL,
                          "CORONAL":const.CORONAL,
@@ -467,6 +559,8 @@ class Controller():
         proj.dicom_sample = dicom
         proj.original_orientation =\
                     name_to_const[dicom.image.orientation_label]
+        # Forcing to Axial
+        #  proj.original_orientation = const.AXIAL
         proj.window = float(dicom.image.window)
         proj.level = float(dicom.image.level)
         proj.threshold_range = int(matrix.min()), int(matrix.max())
@@ -481,6 +575,161 @@ class Controller():
         dirpath = session.CreateProject(filename)
         #proj.SavePlistProject(dirpath, filename)
 
+
+    def CreateBitmapProject(self, bmp_data, rec_data, matrix, matrix_filename):
+        name_to_const = {"AXIAL":const.AXIAL,
+                         "CORONAL":const.CORONAL,
+                         "SAGITTAL":const.SAGITAL}
+
+        name = rec_data[0]
+        orientation = rec_data[1]
+        sp_x = float(rec_data[2])
+        sp_y = float(rec_data[3])
+        sp_z = float(rec_data[4])
+        interval = int(rec_data[5])
+        
+        bits = bmp_data.GetFirstPixelSize()
+        sx, sy = size =  bmp_data.GetFirstBitmapSize()
+        
+        proj = prj.Project()
+        proj.name = name
+        proj.modality = 'UNKNOWN'
+        proj.SetAcquisitionModality(proj.modality)
+        proj.matrix_shape = matrix.shape
+        proj.matrix_dtype = matrix.dtype.name
+        proj.matrix_filename = matrix_filename
+        #proj.imagedata = imagedata
+        #proj.dicom_sample = dicom
+
+        proj.original_orientation =\
+                    name_to_const[orientation.upper()]
+        proj.window = float(matrix.max())
+        proj.level = float(matrix.max()/4)
+        
+        proj.threshold_range = int(matrix.min()), int(matrix.max())
+        #const.THRESHOLD_RANGE = proj.threshold_range
+
+        proj.spacing = self.Slice.spacing
+
+        ######
+        session = ses.Session()
+        filename = proj.name+".inv3"
+
+        filename = filename.replace("/", "") #Fix problem case other/Skull_DICOM
+
+        dirpath = session.CreateProject(filename)
+
+    def CreateOtherProject(self, name, matrix, matrix_filename):
+        name_to_const = {"AXIAL": const.AXIAL,
+                         "CORONAL": const.CORONAL,
+                         "SAGITTAL": const.SAGITAL}
+
+        proj = prj.Project()
+        proj.name = name
+        proj.modality = 'MRI'
+        proj.SetAcquisitionModality('MRI')
+        proj.matrix_shape = matrix.shape
+        proj.matrix_dtype = matrix.dtype.name
+        proj.matrix_filename = matrix_filename
+
+        # Orientation must be CORONAL in order to as_closes_canonical and
+        # swap axis in img2memmap to work in a standardized way.
+        # TODO: Create standard import image for all acquisition orientations
+        orientation = 'CORONAL'
+
+        proj.original_orientation =\
+            name_to_const[orientation]
+
+        proj.window = self.Slice.window_width
+        proj.level = self.Slice.window_level
+        proj.threshold_range = int(matrix.min()), int(matrix.max())
+        proj.spacing = self.Slice.spacing
+
+        ######
+        session = ses.Session()
+        filename = proj.name + ".inv3"
+
+        filename = filename.replace("/", "")  # Fix problem case other/Skull_DICOM
+
+        dirpath = session.CreateProject(filename)
+
+    def OnOpenBitmapFiles(self, pubsub_evt):
+        rec_data = pubsub_evt.data
+        bmp_data = bmp.BitmapData()
+
+        if bmp_data.IsAllBitmapSameSize():
+
+            matrix, matrix_filename = self.OpenBitmapFiles(bmp_data, rec_data)
+            
+            self.CreateBitmapProject(bmp_data, rec_data, matrix, matrix_filename)
+
+            self.LoadProject()
+            Publisher.sendMessage("Enable state project", True)
+        else:
+            dialogs.BitmapNotSameSize()
+
+    def OpenBitmapFiles(self, bmp_data, rec_data):
+
+       name = rec_data[0]
+       orientation = rec_data[1]
+       sp_x = float(rec_data[2])
+       sp_y = float(rec_data[3])
+       sp_z = float(rec_data[4])
+       interval = int(rec_data[5])
+       
+       interval += 1
+       
+       filelist = bmp_data.GetOnlyBitmapPath()[::interval]
+       bits = bmp_data.GetFirstPixelSize()
+
+       sx, sy = size =  bmp_data.GetFirstBitmapSize()
+       n_slices = len(filelist)
+       resolution_percentage = utils.calculate_resizing_tofitmemory(int(sx), int(sy), n_slices, bits/8)
+       
+       zspacing = sp_z * interval
+       xyspacing = (sp_y, sp_x)
+
+       if resolution_percentage < 1.0:
+
+           re_dialog = dialog.ResizeImageDialog()
+           re_dialog.SetValue(int(resolution_percentage*100))
+           re_dialog_value = re_dialog.ShowModal()
+           re_dialog.Close() 
+           
+           if re_dialog_value == wx.ID_OK:
+               percentage = re_dialog.GetValue()
+               resolution_percentage = percentage / 100.0
+           else:
+               return
+
+           xyspacing = xyspacing[0] / resolution_percentage, xyspacing[1] / resolution_percentage
+ 
+
+       
+       self.matrix, scalar_range, self.filename = image_utils.bitmap2memmap(filelist, size,
+                                                               orientation, (sp_z, sp_y, sp_x),resolution_percentage)
+
+
+       self.Slice = sl.Slice()
+       self.Slice.matrix = self.matrix
+       self.Slice.matrix_filename = self.filename
+
+       if orientation == 'AXIAL':
+           self.Slice.spacing = xyspacing[0], xyspacing[1], zspacing
+       elif orientation == 'CORONAL':
+           self.Slice.spacing = xyspacing[0], zspacing, xyspacing[1]
+       elif orientation == 'SAGITTAL':
+           self.Slice.spacing = zspacing, xyspacing[1], xyspacing[0]
+       
+       self.Slice.window_level = float(self.matrix.max()/4)
+       self.Slice.window_width = float(self.matrix.max())
+
+       scalar_range = int(self.matrix.min()), int(self.matrix.max())
+       Publisher.sendMessage('Update threshold limits list', scalar_range)
+
+       return self.matrix, self.filename#, dicom
+
+
     def OnOpenDicomGroup(self, pubsub_evt):
         group, interval, file_range = pubsub_evt.data
         matrix, matrix_filename, dicom = self.OpenDicomGroup(group, interval, file_range, gui=True)
@@ -488,6 +737,21 @@ class Controller():
         self.LoadProject()
         Publisher.sendMessage("Enable state project", True)
 
+    def OnOpenOtherFiles(self, pubsub_evt):
+        filepath = pubsub_evt.data
+        if not(filepath) == None:
+            name = filepath.rpartition('\\')[-1].split('.')
+
+            group = oth.ReadOthers(filepath)
+            
+            if group:
+                matrix, matrix_filename = self.OpenOtherFiles(group)
+                self.CreateOtherProject(str(name[0]), matrix, matrix_filename)
+                self.LoadProject()
+                Publisher.sendMessage("Enable state project", True)
+            else:
+                dialog.ImportInvalidFiles(ftype="Others")
+
     def OpenDicomGroup(self, dicom_group, interval, file_range, gui=True):
         # Retrieve general DICOM headers
         dicom = dicom_group.GetDicomSample()
@@ -573,6 +837,30 @@ class Controller():
 
         return self.matrix, self.filename, dicom
 
+    def OpenOtherFiles(self, group):
+        # Retreaving matrix from image data
+        self.matrix, scalar_range, self.filename = image_utils.img2memmap(group)
+
+        hdr = group.header
+        hdr.set_data_dtype('int16')
+        dims = hdr.get_zooms()
+        dimsf = tuple([float(s) for s in dims])
+
+        wl = float((scalar_range[0] + scalar_range[1]) * 0.5)
+        ww = float((scalar_range[1] - scalar_range[0]))
+
+        self.Slice = sl.Slice()
+        self.Slice.matrix = self.matrix
+        self.Slice.matrix_filename = self.filename
+
+        self.Slice.spacing = dimsf
+        self.Slice.window_level = wl
+        self.Slice.window_width = ww
+
+        scalar_range = int(scalar_range[0]), int(scalar_range[1])
+        Publisher.sendMessage('Update threshold limits list', scalar_range)
+        return self.matrix, self.filename
+
     def LoadImagedataInfo(self):
         proj = prj.Project()
 
@@ -631,3 +919,6 @@ class Controller():
     def ShowBooleanOpDialog(self, pubsub_evt):
         dlg = dialogs.MaskBooleanDialog(prj.Project().mask_dict)
         dlg.Show()
+
+    def ApplyReorientation(self, pubsub_evt):
+        self.Slice.apply_reorientation()
