@@ -23,7 +23,18 @@ import vtk
 import wx
 from wx.lib.pubsub import pub as Publisher
 
-import vtk_utils as vu
+import invesalius.constants as const
+import invesalius.data.vtk_utils as vu
+from invesalius.utils import touch
+
+if sys.platform == 'win32':
+    try:
+        import win32api
+        _has_win32api = True
+    except ImportError:
+        _has_win32api = False
+else:
+    _has_win32api = False
 
 # Update progress value in GUI
 UpdateProgress = vu.ShowProgress()
@@ -97,17 +108,22 @@ def Merge(polydata_list):
     for polydata in polydata_list:
         triangle = vtk.vtkTriangleFilter()
         triangle.SetInputData(polydata)
+        triangle.Update()
         append.AddInputData(triangle.GetOutput())
 
+    append.Update()
     clean = vtk.vtkCleanPolyData()
     clean.SetInputData(append.GetOutput())
+    clean.Update()
 
     return append.GetOutput()
 
 def Export(polydata, filename, bin=False):
     writer = vtk.vtkXMLPolyDataWriter()
-    print filename, type(filename)
-    writer.SetFileName(filename.encode('utf-8'))
+    if _has_win32api:
+        touch(filename)
+        filename = win32api.GetShortPathName(filename)
+    writer.SetFileName(filename.encode(const.FS_ENCODE))
     if bin:
         writer.SetDataModeToBinary()
     else:
