@@ -17,9 +17,10 @@
 #    detalhes.
 #--------------------------------------------------------------------------
 import vtk
+import wx
 
-import constants as const
-import vtk_utils as vu
+import invesalius.constants as const
+import invesalius.data.vtk_utils as vu
 
 BORDER_UP = 1
 BORDER_DOWN = 2
@@ -38,6 +39,7 @@ class SliceData(object):
         self.number = 0
         self.orientation = 'AXIAL'
         self.renderer = None
+        self.canvas_renderer = None
         self.overlay_renderer = None
         self.__create_text()
         self.__create_box()
@@ -49,6 +51,7 @@ class SliceData(object):
         text.SetColour(colour)
         text.SetSize(const.TEXT_SIZE_LARGE)
         text.SetPosition(const.TEXT_POS_LEFT_DOWN_ZERO)
+        text.SetSymbolicSize(wx.FONTSIZE_LARGE)
         #text.SetVerticalJustificationToBottom()
         text.SetValue(self.number)
         self.text = text
