@@ -21,6 +21,8 @@ import multiprocessing
 import os
 import plistlib
 import random
+import shutil
+import sys
 import tempfile
 import weakref
 
@@ -28,20 +30,25 @@ import vtk
 import wx
 from wx.lib.pubsub import pub as Publisher
 
-import constants as const
-import imagedata_utils as iu
-import polydata_utils as pu
-import project as prj
-import session as ses
-import surface_process
-import utils as utl
-import vtk_utils as vu
+if sys.platform == 'win32':
+    try:
+        import win32api
+        _has_win32api = True
+    except ImportError:
+        _has_win32api = False
+else:
+    _has_win32api = False
 
-try:
-    import ca_smoothing
-except ImportError:
-    import data.ca_smoothing as ca_smoothing
+import invesalius.constants as const
+import invesalius.data.imagedata_utils as iu
+import invesalius.data.polydata_utils as pu
+import invesalius.project as prj
+import invesalius.session as ses
+import invesalius.data.surface_process as surface_process
+import invesalius.utils as utl
+import invesalius.data.vtk_utils as vu
 
+from invesalius.data import cy_mesh
 # TODO: Verificar ReleaseDataFlagOn and SetSource 
 
 class Surface():
@@ -68,8 +75,8 @@ class Surface():
             self.name = name
 
     def SavePlist(self, dir_temp, filelist):
-        filename = 'surface_%d' % self.index
-        vtp_filename = filename + '.vtp'
+        filename = u'surface_%d' % self.index
+        vtp_filename = filename + u'.vtp'
         vtp_filepath = os.path.join(dir_temp, vtp_filename)
         pu.Export(self.polydata, vtp_filepath, bin=True)
 
@@ -84,7 +91,7 @@ class Surface():
                    'volume': self.volume,
                    'area': self.area,
                   }
-        plist_filename = filename + '.plist'
+        plist_filename = filename + u'.plist'
         #plist_filepath = os.path.join(dir_temp, filename + '.plist')
         temp_plist = tempfile.mktemp()
         plistlib.writePlist(surface, temp_plist)
@@ -154,6 +161,8 @@ class SurfaceManager():
         Publisher.subscribe(self.OnRemove,"Remove surfaces")
         Publisher.subscribe(self.UpdateSurfaceInterpolation, 'Update Surface Interpolation')
 
+        Publisher.subscribe(self.OnImportSurfaceFile, 'Import surface file')
+
     def OnDuplicate(self, pubsub_evt):
         selected_items = pubsub_evt.data
         proj = prj.Project()
@@ -245,6 +254,40 @@ class SurfaceManager():
         new_index = self.CreateSurfaceFromPolydata(new_polydata)
         Publisher.sendMessage('Show single surface', (new_index, True))
 
+    def OnImportSurfaceFile(self, pubsub_evt):
+        """
+        Creates a new surface from a surface file (STL, PLY, OBJ or VTP)
+        """
+        filename = pubsub_evt.data
+        self.CreateSurfaceFromFile(filename)
+
+    def CreateSurfaceFromFile(self, filename):
+        if filename.lower().endswith('.stl'):
+            reader = vtk.vtkSTLReader()
+        elif filename.lower().endswith('.ply'):
+            reader = vtk.vtkPLYReader()
+        elif filename.lower().endswith('.obj'):
+            reader = vtk.vtkOBJReader()
+        elif filename.lower().endswith('.vtp'):
+            reader = vtk.vtkXMLPolyDataReader()
+        else:
+            wx.MessageBox(_("File format not reconized by InVesalius"), _("Import surface error"))
+            return
+
+        if _has_win32api:
+            reader.SetFileName(win32api.GetShortPathName(filename).encode(const.FS_ENCODE))
+        else:
+            reader.SetFileName(filename.encode(const.FS_ENCODE))
+
+        reader.Update()
+        polydata = reader.GetOutput()
+
+        if polydata.GetNumberOfPoints() == 0:
+            wx.MessageBox(_("InVesalius was not able to import this surface"), _("Import surface error"))
+        else:
+            name = os.path.splitext(os.path.split(filename)[-1])[0]
+            self.CreateSurfaceFromPolydata(polydata, name=name)
+
     def CreateSurfaceFromPolydata(self, polydata, overwrite=False,
                                   name=None, colour=None,
                                   transparency=None, volume=None, area=None):
@@ -333,6 +376,9 @@ class SurfaceManager():
         del self.actors_dict
         self.actors_dict = {}
 
+        # restarting the surface index
+        Surface.general_index = -1
+
     def OnSelectSurface(self, pubsub_evt):
         index = pubsub_evt.data
         #self.last_surface_index = index
@@ -344,8 +390,8 @@ class SurfaceManager():
                                surface.colour, surface.volume,
                                surface.area, surface.transparency))
         self.last_surface_index = index
-        if surface.is_shown:
-            self.ShowActor(index, True)
+        #  if surface.is_shown:
+        self.ShowActor(index, True)
 
     def OnLoadSurfaceDict(self, pubsub_evt):
         surface_dict = pubsub_evt.data
@@ -564,17 +610,24 @@ class SurfaceManager():
             #  polydata.SetSource(None)
             del clean
 
-            try:
-                polydata.BuildLinks()
-            except TypeError:
-                polydata.BuildLinks(0)
-            polydata = ca_smoothing.ca_smoothing(polydata, options['angle'],
-                                                 options['max distance'],
-                                                 options['min weight'],
-                                                 options['steps'])
+            #  try:
+                #  polydata.BuildLinks()
+            #  except TypeError:
+                #  polydata.BuildLinks(0)
+            #  polydata = ca_smoothing.ca_smoothing(polydata, options['angle'],
+                                                 #  options['max distance'],
+                                                 #  options['min weight'],
+                                                 #  options['steps'])
+
+            mesh = cy_mesh.Mesh(polydata)
+            cy_mesh.ca_smoothing(mesh, options['angle'],
+                                 options['max distance'],
+                                 options['min weight'],
+                                 options['steps'])
+            #  polydata = mesh.to_vtk()
+
             #  polydata.SetSource(None)
             #  polydata.DebugOn()
-
         else:
             #smoother = vtk.vtkWindowedSincPolyDataFilter()
             smoother = vtk.vtkSmoothPolyDataFilter()
@@ -831,11 +884,31 @@ class SurfaceManager():
 
     def OnExportSurface(self, pubsub_evt):
         filename, filetype = pubsub_evt.data
-        if (filetype == const.FILETYPE_STL) or\
-           (filetype == const.FILETYPE_VTP) or\
-           (filetype == const.FILETYPE_PLY) or\
-           (filetype == const.FILETYPE_STL_ASCII):
+        ftype_prefix = {
+            const.FILETYPE_STL: '.stl',
+            const.FILETYPE_VTP: '.vtp',
+            const.FILETYPE_PLY: '.ply',
+            const.FILETYPE_STL_ASCII: '.stl',
+        }
+        if filetype in ftype_prefix:
+            temp_file = tempfile.mktemp(suffix=ftype_prefix[filetype])
 
+            if _has_win32api:
+                utl.touch(temp_file)
+                _temp_file = temp_file
+                temp_file = win32api.GetShortPathName(temp_file)
+                os.remove(_temp_file)
+
+            temp_file = temp_file.decode(const.FS_ENCODE)
+            self._export_surface(temp_file, filetype)
+
+            shutil.move(temp_file, filename)
+
+    def _export_surface(self, filename, filetype):
+        if filetype in (const.FILETYPE_STL,
+                        const.FILETYPE_VTP,
+                        const.FILETYPE_PLY,
+                        const.FILETYPE_STL_ASCII):
             # First we identify all surfaces that are selected
             # (if any)
             proj = prj.Project()
@@ -874,7 +947,9 @@ class SurfaceManager():
                 #writer.SetColorModeToUniformCellColor()
                 #writer.SetColor(255, 0, 0)
 
-            if filetype in (const.FILETYPE_STL, const.FILETYPE_PLY):
+            if filetype in (const.FILETYPE_STL,
+                            const.FILETYPE_STL_ASCII,
+                            const.FILETYPE_PLY):
                 # Invert normals
                 normals = vtk.vtkPolyDataNormals()
                 normals.SetInputData(polydata)
@@ -885,7 +960,7 @@ class SurfaceManager():
                 normals.Update()
                 polydata = normals.GetOutput()
 
-            filename = filename.encode(wx.GetDefaultPyEncoding())
+            filename = filename.encode(const.FS_ENCODE)
             writer.SetFileName(filename)
             writer.SetInputData(polydata)
             writer.Write()
