@@ -25,13 +25,13 @@ import vtk
 import wx
 from wx.lib.pubsub import pub as Publisher
 
-import constants as const
-import project as prj
-import slice_
-import converters
-from data import vtk_utils
+import invesalius.constants as const
+import invesalius.project as prj
+import invesalius.data.slice_ as slice_
+import invesalius.data.converters as converters
+import invesalius.data.vtk_utils as vtk_utils
 from vtk.util import numpy_support
-import session as ses
+import invesalius.session as ses
 
 
 Kernels = { 
@@ -131,11 +131,29 @@ class Volume():
             self.plane.DestroyObjs()
             del self.plane
             self.plane = 0
-            
+
         if self.exist:
             self.exist = None
             Publisher.sendMessage('Remove surface actor from viewer', self.volume)
             Publisher.sendMessage('Disable volume cut menu')
+            Publisher.sendMessage('Unload volume', self.volume)
+
+            del self.image
+            del self.imagedata
+            del self.final_imagedata
+            del self.volume
+            del self.color_transfer
+            del self.opacity_transfer_func
+            del self.volume_properties
+            del self.volume_mapper
+            self.volume = None
+            self.exist = False
+            self.loaded_image = False
+            self.image = None
+            self.final_imagedata = None
+            self.opacity_transfer_func = None
+            self.color_transfer = None
+            Publisher.sendMessage('Render volume viewer')
 
     def OnLoadVolume(self, pubsub_evt):
         label = pubsub_evt.data
@@ -143,18 +161,22 @@ class Volume():
         self.LoadVolume()
 
     def OnHideVolume(self, pubsub_evt):
+        print 'Hide Volume'
         self.volume.SetVisibility(0)
         if (self.plane and self.plane_on):
             self.plane.Disable()
         Publisher.sendMessage('Render volume viewer')
 
     def OnShowVolume(self, pubsub_evt = None):
+        print 'Show volume'
         if self.exist:
+            print 'Volume exists'
             self.volume.SetVisibility(1)
             if (self.plane and self.plane_on):
                 self.plane.Enable()
             Publisher.sendMessage('Render volume viewer')
         else:
+            print 'Volume doesnt exit'
             Publisher.sendMessage('Load raycasting preset', const.RAYCASTING_LABEL)
             self.LoadConfig()
             self.LoadVolume()
@@ -339,12 +361,17 @@ class Volume():
             g = p['Green']
             b = p['Blue']
             colors = zip(r,g,b)
-            ww = self.config['ww']
-            wl = self.TranslateScale(scale, self.config['wl'])
-            init = wl - ww/2.0
-            inc = ww / (len(colors) - 1.0)
-            for n,rgb in enumerate(colors):
-                color_transfer.AddRGBPoint(init + n * inc, *[i/255.0 for i in rgb])
+        else:
+            # Grayscale from black to white
+            colors = [(i, i, i) for i in xrange(256)]
+
+        ww = self.config['ww']
+        wl = self.TranslateScale(scale, self.config['wl'])
+        init = wl - ww/2.0
+        inc = ww / (len(colors) - 1.0)
+        for n,rgb in enumerate(colors):
+            color_transfer.AddRGBPoint(init + n * inc, *[i/255.0 for i in rgb])
+
         self.color_transfer = color_transfer
 
     def CreateOpacityTable(self, scale):
@@ -486,7 +513,7 @@ class Volume():
                 convolve = vtk.vtkImageConvolve()
                 convolve.SetInputData(imagedata)
                 convolve.SetKernel5x5([i/60.0 for i in Kernels[filter]])
-                convolve.ReleaseDataFlagOn()
+                #  convolve.ReleaseDataFlagOn()
 
                 convolve_ref = weakref.ref(convolve)
                 
@@ -533,7 +560,7 @@ class Volume():
         flip.SetInputData(image)
         flip.SetFilteredAxis(1)
         flip.FlipAboutOriginOn()
-        flip.ReleaseDataFlagOn()
+        #  flip.ReleaseDataFlagOn()
 
         flip_ref = weakref.ref(flip)
         flip_ref().AddObserver("ProgressEvent", lambda obj,evt:
@@ -548,7 +575,7 @@ class Volume():
         cast.SetInputData(image)
         cast.SetShift(abs(scale[0]))
         cast.SetOutputScalarTypeToUnsignedShort()
-        cast.ReleaseDataFlagOn()
+        #  cast.ReleaseDataFlagOn()
         cast_ref = weakref.ref(cast)
         cast_ref().AddObserver("ProgressEvent", lambda obj,evt:
                             update_progress(cast_ref(), "Rendering..."))
@@ -632,8 +659,12 @@ class Volume():
 
         self.exist = 1
 
+        if self.plane:
+            self.plane.SetVolumeMapper(volume_mapper)
+
         Publisher.sendMessage('Load volume into viewer',
                                     (volume, colour, (self.ww, self.wl)))
+
         del flip
         del cast
 
@@ -648,7 +679,7 @@ class Volume():
                     self.plane_on = False
                     self.plane.Disable()
             else:
-                self.final_imagedata.Update()
+                #  self.final_imagedata.Update()
                 self.plane_on = True
                 self.plane = CutPlane(self.final_imagedata,
                                       self.volume_mapper)
@@ -660,7 +691,7 @@ class Volume():
         accumulate.SetInputData(image)
         accumulate.SetComponentExtent(0, r -1, 0, 0, 0, 0)
         accumulate.SetComponentOrigin(image.GetScalarRange()[0], 0, 0)
-        accumulate.ReleaseDataFlagOn()
+        #  accumulate.ReleaseDataFlagOn()
         accumulate.Update()
         n_image = numpy_support.vtk_to_numpy(accumulate.GetOutput().GetPointData().GetScalars())
         del accumulate
@@ -692,7 +723,7 @@ class CutPlane:
             
     def Create(self):
         self.plane_widget = plane_widget = vtk.vtkImagePlaneWidget()
-        plane_widget.SetInput(self.img)
+        plane_widget.SetInputData(self.img)
         plane_widget.SetPlaneOrientationToXAxes()
         #plane_widget.SetResliceInterpolateToLinear()
         plane_widget.TextureVisibilityOff()
@@ -710,7 +741,7 @@ class CutPlane:
         plane_source.SetPoint2(plane_widget.GetPoint2())
         plane_source.SetNormal(plane_widget.GetNormal())
         plane_mapper = self.plane_mapper = vtk.vtkPolyDataMapper()
-        plane_mapper.SetInput(plane_source.GetOutput())
+        plane_mapper.SetInputData(plane_source.GetOutput())
         self.plane_actor = plane_actor = vtk.vtkActor()
         plane_actor.SetMapper(plane_mapper)
         plane_actor.GetProperty().BackfaceCullingOn()
@@ -729,7 +760,11 @@ class CutPlane:
         self.p1 = plane_widget.GetPoint1()
         self.p2 = plane_widget.GetPoint2()
         self.normal = plane_widget.GetNormal()
-        
+
+    def SetVolumeMapper(self, volume_mapper):
+        self.volume_mapper = volume_mapper
+        self.volume_mapper.AddClippingPlane(self.plane)
+
     def Update(self, a, b):        
         plane_source = self.plane_source
         plane_widget = self.plane_widget
