@@ -20,6 +20,7 @@
 #--------------------------------------------------------------------------
 import sys
 import platform
+import os
 
 try:
     import Image
@@ -32,14 +33,14 @@ import wx.lib.flatnotebook as fnb
 import wx.lib.platebtn as pbtn
 from wx.lib.pubsub import pub as Publisher
 
-import constants as const
-import data.slice_ as slice_
-import gui.dialogs as dlg
-import gui.widgets.listctrl as listmix
-import utils as ul
+import invesalius.constants as const
+import invesalius.data.slice_ as slice_
+import invesalius.gui.dialogs as dlg
+import invesalius.gui.widgets.listctrl as listmix
+import invesalius.utils as ul
 
 
-BTN_NEW, BTN_REMOVE, BTN_DUPLICATE = [wx.NewId() for i in xrange(3)]
+BTN_NEW, BTN_REMOVE, BTN_DUPLICATE, BTN_OPEN = [wx.NewId() for i in xrange(4)]
 
 TYPE = {const.LINEAR: _(u"Linear"),
         const.ANGULAR: _(u"Angular"),
@@ -148,11 +149,11 @@ class MeasureButtonControlPanel(wx.Panel):
     def __init_gui(self):
 
         # Bitmaps to be used in plate buttons
-        BMP_NEW = wx.Bitmap("../icons/data_new.png",
+        BMP_NEW = wx.Bitmap(os.path.join(const.ICON_DIR, "data_new.png"),
                             wx.BITMAP_TYPE_PNG)
-        BMP_REMOVE = wx.Bitmap("../icons/data_remove.png",
+        BMP_REMOVE = wx.Bitmap(os.path.join(const.ICON_DIR, "data_remove.png"),
                                 wx.BITMAP_TYPE_PNG)
-        BMP_DUPLICATE = wx.Bitmap("../icons/data_duplicate.png",
+        BMP_DUPLICATE = wx.Bitmap(os.path.join(const.ICON_DIR, "data_duplicate.png"),
                                 wx.BITMAP_TYPE_PNG)
 
         # Plate buttons based on previous bitmaps
@@ -161,15 +162,20 @@ class MeasureButtonControlPanel(wx.Panel):
                                      BMP_NEW,
                                      style=button_style,
                                      size = wx.Size(24, 20))
+        button_new.SetToolTipString(_("Create a new measure"))
         self.button_new = button_new
+
         button_remove = pbtn.PlateButton(self, BTN_REMOVE, "",
                                          BMP_REMOVE,
                                          style=button_style,
                                          size = wx.Size(24, 20))
+        button_remove.SetToolTipString(_("Remove measure"))
+
         button_duplicate = pbtn.PlateButton(self, BTN_DUPLICATE, "",
                                             BMP_DUPLICATE,
                                             style=button_style,
                                             size = wx.Size(24, 20))
+        button_duplicate.SetToolTipString(_("Duplicate measure"))
         button_duplicate.Disable()
 
         # Add all controls to gui
@@ -261,11 +267,11 @@ class ButtonControlPanel(wx.Panel):
     def __init_gui(self):
 
         # Bitmaps to be used in plate buttons
-        BMP_NEW = wx.Bitmap("../icons/data_new.png",
+        BMP_NEW = wx.Bitmap(os.path.join(const.ICON_DIR, "data_new.png"),
                             wx.BITMAP_TYPE_PNG)
-        BMP_REMOVE = wx.Bitmap("../icons/data_remove.png",
+        BMP_REMOVE = wx.Bitmap(os.path.join(const.ICON_DIR, "data_remove.png"),
                                 wx.BITMAP_TYPE_PNG)
-        BMP_DUPLICATE = wx.Bitmap("../icons/data_duplicate.png",
+        BMP_DUPLICATE = wx.Bitmap(os.path.join(const.ICON_DIR, "data_duplicate.png"),
                                 wx.BITMAP_TYPE_PNG)
 
         # Plate buttons based on previous bitmaps
@@ -274,14 +280,19 @@ class ButtonControlPanel(wx.Panel):
                                      BMP_NEW,
                                      style=button_style,
                                      size = wx.Size(24, 20))
+        button_new.SetToolTipString(_("Create a new mask"))
+
         button_remove = pbtn.PlateButton(self, BTN_REMOVE, "",
                                          BMP_REMOVE,
                                          style=button_style,
                                          size = wx.Size(24, 20))
+        button_remove.SetToolTipString(_("Remove mask"))
+
         button_duplicate = pbtn.PlateButton(self, BTN_DUPLICATE, "",
                                             BMP_DUPLICATE,
                                             style=button_style,
                                             size = wx.Size(24, 20))
+        button_duplicate.SetToolTipString(_("Duplicate mask"))
 
         # Add all controls to gui
         sizer = wx.BoxSizer(wx.HORIZONTAL)
@@ -364,6 +375,7 @@ class MasksListCtrlPanel(wx.ListCtrl, listmix.TextEditMixin):
 
         Publisher.subscribe(self.OnChangeCurrentMask, 'Change mask selected')
         Publisher.subscribe(self.__hide_current_mask, 'Hide current mask')
+        Publisher.subscribe(self.__show_current_mask, 'Show current mask')
         Publisher.subscribe(self.OnCloseProject, 'Close project data')
 
     def OnKeyEvent(self, event):
@@ -435,6 +447,9 @@ class MasksListCtrlPanel(wx.ListCtrl, listmix.TextEditMixin):
     def __hide_current_mask(self, pubsub_evt):
         self.SetItemImage(self.current_index, 0)
 
+    def __show_current_mask(self, pubsub_evt):
+        self.SetItemImage(self.current_index, 1)
+
     def __init_columns(self):
 
         self.InsertColumn(0, "", wx.LIST_FORMAT_CENTER)
@@ -448,13 +463,13 @@ class MasksListCtrlPanel(wx.ListCtrl, listmix.TextEditMixin):
     def __init_image_list(self):
         self.imagelist = wx.ImageList(16, 16)
 
-        image = wx.Image("../icons/object_invisible.jpg")
+        image = wx.Image(os.path.join(const.ICON_DIR, "object_invisible.jpg"))
         bitmap = wx.BitmapFromImage(image.Scale(16, 16))
         bitmap.SetWidth(16)
         bitmap.SetHeight(16)
         img_null = self.imagelist.Add(bitmap)
 
-        image = wx.Image("../icons/object_visible.jpg")
+        image = wx.Image(os.path.join(const.ICON_DIR, "object_visible.jpg"))
         bitmap = wx.BitmapFromImage(image.Scale(16, 16))
         bitmap.SetWidth(16)
         bitmap.SetHeight(16)
@@ -462,7 +477,7 @@ class MasksListCtrlPanel(wx.ListCtrl, listmix.TextEditMixin):
 
         self.SetImageList(self.imagelist,wx.IMAGE_LIST_SMALL)
 
-        self.image_gray = Image.open("../icons/object_colour.jpg")
+        self.image_gray = Image.open(os.path.join(const.ICON_DIR, "object_colour.jpg"))
 
     def OnEditLabel(self, evt):
         Publisher.sendMessage('Change mask name',
@@ -508,11 +523,11 @@ class MasksListCtrlPanel(wx.ListCtrl, listmix.TextEditMixin):
         self.SetStringItem(index, 1, label,
                            imageId=self.mask_list_index[index])
         self.SetStringItem(index, 2, threshold)
-        self.SetItemImage(index, 1)
-        for key in self.mask_list_index.keys():
-            if key != index:
-                self.SetItemImage(key, 0)
-        self.current_index = index
+        #  self.SetItemImage(index, 1)
+        #  for key in self.mask_list_index.keys():
+            #  if key != index:
+                #  self.SetItemImage(key, 0)
+        #  self.current_index = index
 
     def AddMask(self, pubsub_evt):
         index, mask_name, threshold_range, colour = pubsub_evt.data
@@ -582,11 +597,13 @@ class SurfaceButtonControlPanel(wx.Panel):
     def __init_gui(self):
 
         # Bitmaps to be used in plate buttons
-        BMP_NEW = wx.Bitmap("../icons/data_new.png",
+        BMP_NEW = wx.Bitmap(os.path.join(const.ICON_DIR, "data_new.png"),
                             wx.BITMAP_TYPE_PNG)
-        BMP_REMOVE = wx.Bitmap("../icons/data_remove.png",
+        BMP_REMOVE = wx.Bitmap(os.path.join(const.ICON_DIR, "data_remove.png"),
                                 wx.BITMAP_TYPE_PNG)
-        BMP_DUPLICATE = wx.Bitmap("../icons/data_duplicate.png",
+        BMP_DUPLICATE = wx.Bitmap(os.path.join(const.ICON_DIR, "data_duplicate.png"),
+                                wx.BITMAP_TYPE_PNG)
+        BMP_OPEN = wx.Bitmap(os.path.join(const.ICON_DIR, "load_mesh.png"),
                                 wx.BITMAP_TYPE_PNG)
 
         # Plate buttons based on previous bitmaps
@@ -595,20 +612,32 @@ class SurfaceButtonControlPanel(wx.Panel):
                                      BMP_NEW,
                                      style=button_style,
                                      size = wx.Size(24, 20))
+        button_new.SetToolTipString(_("Create a new surface"))
+
         button_remove = pbtn.PlateButton(self, BTN_REMOVE, "",
                                          BMP_REMOVE,
                                          style=button_style,
                                          size = wx.Size(24, 20))
+        button_remove.SetToolTipString(_("Remove surface"))
+
         button_duplicate = pbtn.PlateButton(self, BTN_DUPLICATE, "",
                                             BMP_DUPLICATE,
                                             style=button_style,
                                             size = wx.Size(24, 20))
+        button_duplicate.SetToolTipString(_("Duplicate surface"))
+
+        button_open = pbtn.PlateButton(self, BTN_OPEN, "",
+                                       BMP_OPEN,
+                                       style=button_style,
+                                       size = wx.Size(24, 20))
+        button_open.SetToolTipString(_("Import a surface file into InVesalius"))
 
         # Add all controls to gui
         sizer = wx.BoxSizer(wx.HORIZONTAL)
         sizer.Add(button_new, 0, wx.GROW|wx.EXPAND|wx.LEFT)
         sizer.Add(button_remove, 0, wx.GROW|wx.EXPAND)
         sizer.Add(button_duplicate, 0, wx.GROW|wx.EXPAND)
+        sizer.Add(button_open, 0, wx.GROW|wx.EXPAND)
         self.SetSizer(sizer)
         self.Fit()
 
@@ -623,6 +652,8 @@ class SurfaceButtonControlPanel(wx.Panel):
             self.OnRemove()
         elif id ==  BTN_DUPLICATE:
             self.OnDuplicate()
+        elif id == BTN_OPEN:
+            self.OnOpenMesh()
 
     def OnNew(self):
         sl = slice_.Slice()
@@ -654,6 +685,11 @@ class SurfaceButtonControlPanel(wx.Panel):
         else:
            dlg.SurfaceSelectionRequiredForDuplication()
 
+    def OnOpenMesh(self):
+        filename = dlg.ShowImportMeshFilesDialog()
+        if filename:
+            Publisher.sendMessage('Import surface file', filename)
+
 
 class SurfacesListCtrlPanel(wx.ListCtrl, listmix.TextEditMixin):
 
@@ -777,13 +813,13 @@ class SurfacesListCtrlPanel(wx.ListCtrl, listmix.TextEditMixin):
     def __init_image_list(self):
         self.imagelist = wx.ImageList(16, 16)
 
-        image = wx.Image("../icons/object_invisible.jpg")
+        image = wx.Image(os.path.join(const.ICON_DIR, "object_invisible.jpg"))
         bitmap = wx.BitmapFromImage(image.Scale(16, 16))
         bitmap.SetWidth(16)
         bitmap.SetHeight(16)
         img_null = self.imagelist.Add(bitmap)
 
-        image = wx.Image("../icons//object_visible.jpg")
+        image = wx.Image(os.path.join(const.ICON_DIR, "object_visible.jpg"))
         bitmap = wx.BitmapFromImage(image.Scale(16, 16))
         bitmap.SetWidth(16)
         bitmap.SetHeight(16)
@@ -791,7 +827,7 @@ class SurfacesListCtrlPanel(wx.ListCtrl, listmix.TextEditMixin):
 
         self.SetImageList(self.imagelist,wx.IMAGE_LIST_SMALL)
 
-        self.image_gray = Image.open("../icons/object_colour.jpg")
+        self.image_gray = Image.open(os.path.join(const.ICON_DIR, "object_colour.jpg"))
 
     def OnEditLabel(self, evt):
         Publisher.sendMessage('Change surface name', (evt.GetIndex(), evt.GetLabel()))
@@ -939,6 +975,7 @@ class MeasuresListCtrlPanel(wx.ListCtrl, listmix.TextEditMixin):
         Publisher.subscribe(self.OnShowSingle, 'Show single measurement')
         Publisher.subscribe(self.OnShowMultiple, 'Show multiple measurements')
         Publisher.subscribe(self.OnLoadData, 'Load measurement dict')
+        Publisher.subscribe(self.OnRemoveGUIMeasure, 'Remove GUI measurement')
 
     def __bind_events_wx(self):
         self.Bind(wx.EVT_LIST_ITEM_ACTIVATED, self.OnItemActivated)
@@ -955,6 +992,19 @@ class MeasuresListCtrlPanel(wx.ListCtrl, listmix.TextEditMixin):
         elif (keycode == wx.WXK_DELETE):
             self.RemoveMeasurements()
 
+    def OnRemoveGUIMeasure(self, pubsub_evt):
+        idx = pubsub_evt.data
+        self.DeleteItem(idx)
+
+        old_dict = self._list_index
+        new_dict = {}
+        j = 0
+        for i in old_dict:
+            if i != idx:
+                new_dict[j] = old_dict[i]
+                j+=1
+        self._list_index = new_dict
+
     def RemoveMeasurements(self):
         """
         Remove items selected.
@@ -1027,13 +1077,13 @@ class MeasuresListCtrlPanel(wx.ListCtrl, listmix.TextEditMixin):
     def __init_image_list(self):
         self.imagelist = wx.ImageList(16, 16)
 
-        image = wx.Image("../icons/object_invisible.jpg")
+        image = wx.Image(os.path.join(const.ICON_DIR, "object_invisible.jpg"))
         bitmap = wx.BitmapFromImage(image.Scale(16, 16))
         bitmap.SetWidth(16)
         bitmap.SetHeight(16)
         img_null = self.imagelist.Add(bitmap)
 
-        image = wx.Image("../icons/object_visible.jpg")
+        image = wx.Image(os.path.join(const.ICON_DIR, "object_visible.jpg"))
         bitmap = wx.BitmapFromImage(image.Scale(16, 16))
         bitmap.SetWidth(16)
         bitmap.SetHeight(16)
@@ -1041,7 +1091,7 @@ class MeasuresListCtrlPanel(wx.ListCtrl, listmix.TextEditMixin):
 
         self.SetImageList(self.imagelist,wx.IMAGE_LIST_SMALL)
 
-        self.image_gray = Image.open("../icons/object_colour.jpg")
+        self.image_gray = Image.open(os.path.join(const.ICON_DIR, "object_colour.jpg"))
 
 
     def OnEditLabel(self, evt):
@@ -1101,7 +1151,7 @@ class MeasuresListCtrlPanel(wx.ListCtrl, listmix.TextEditMixin):
                 value = (u"%.2f°") % m.value
             self.InsertNewItem(m.index, m.name, colour, location, type, value)
 
-            if not m.is_shown:
+            if not m.visible:
                 self.SetItemImage(i, False)
 
     def AddItem_(self, pubsub_evt):
@@ -1123,6 +1173,8 @@ class MeasuresListCtrlPanel(wx.ListCtrl, listmix.TextEditMixin):
                 self.UpdateItemInfo(index, name, colour, location, type_, value)
             else:
                 self.InsertNewItem(index, name, colour, location, type_, value)
+        else:
+            self.UpdateItemInfo(index, name, colour, location, type_, value)
 
 
 
@@ -1138,7 +1190,7 @@ class MeasuresListCtrlPanel(wx.ListCtrl, listmix.TextEditMixin):
         self.Refresh()
 
     def UpdateItemInfo(self, index=0, label="Measurement 1", colour=None,
-                      type_="LINEAR", location="SURFACE", value="0 mm"):
+                      location="SURFACE", type_="LINEAR", value="0 mm"):
         self.SetStringItem(index, 1, label,
                             imageId = self._list_index[index])
         self.SetStringItem(index, 2, location)
@@ -1220,19 +1272,19 @@ class AnnotationsListCtrlPanel(wx.ListCtrl, listmix.TextEditMixin):
     def __init_image_list(self):
         self.imagelist = wx.ImageList(16, 16)
 
-        image = wx.Image("../icons/object_visible.jpg")
+        image = wx.Image(os.path.join(const.ICON_DIR, "object_visible.jpg"))
         bitmap = wx.BitmapFromImage(image.Scale(16, 16))
         bitmap.SetWidth(16)
         bitmap.SetHeight(16)
         img_check = self.imagelist.Add(bitmap)
 
-        image = wx.Image("../icons/object_invisible.jpg")
+        image = wx.Image(os.path.join(const.ICON_DIR, "object_invisible.jpg"))
         bitmap = wx.BitmapFromImage(image.Scale(16, 16))
         bitmap.SetWidth(16)
         bitmap.SetHeight(16)
         img_null = self.imagelist.Add(bitmap)
 
-        image = wx.Image("../icons/object_colour.jpg")
+        image = wx.Image(os.path.join(const.ICON_DIR, "object_colour.jpg"))
         bitmap = wx.BitmapFromImage(image.Scale(16, 16))
         bitmap.SetWidth(16)
         bitmap.SetHeight(16)
