@@ -21,15 +21,15 @@ import wx
 import wx.lib.foldpanelbar as fpb
 from wx.lib.pubsub import pub as Publisher
 
-import constants as const
-import data_notebook as nb
-import session as ses
-import task_exporter as exporter
-import task_slice as slice_
-import task_importer as importer
-import task_surface as surface
-import task_tools as tools
-import task_navigator as navigator
+import invesalius.constants as const
+import invesalius.gui.data_notebook as nb
+import invesalius.session as ses
+import invesalius.gui.task_exporter as exporter
+import invesalius.gui.task_slice as slice_
+import invesalius.gui.task_importer as importer
+import invesalius.gui.task_surface as surface
+import invesalius.gui.task_tools as tools
+import invesalius.gui.task_navigator as navigator
 
 FPB_DEFAULT_STYLE = 2621440
 
@@ -250,7 +250,8 @@ class UpperTaskPanel(wx.Panel):
             tasks = [(_("Load data"), importer.TaskPanel),
                      (_("Select region of interest"), slice_.TaskPanel),
                      (_("Configure 3D surface"), surface.TaskPanel),
-                     (_("Utilize navigation system"), navigator.TaskPanel)]
+                     (_("Export data"), exporter.TaskPanel),
+                     (_("Navigation system"), navigator.TaskPanel)]
 
         for i in xrange(len(tasks)):
             (name, panel) = tasks[i]
@@ -283,9 +284,11 @@ class UpperTaskPanel(wx.Panel):
 
         fold_panel.Expand(fold_panel.GetFoldPanel(0))
         self.fold_panel = fold_panel
+        self.image_list = image_list
 
         sizer = wx.BoxSizer(wx.VERTICAL)
         sizer.Add(fold_panel, 1, wx.GROW|wx.EXPAND)
+        self.sizer = sizer
         self.SetSizerAndFit(sizer)
 
         self.SetStateProjectClose()
@@ -297,6 +300,7 @@ class UpperTaskPanel(wx.Panel):
         Publisher.subscribe(self.OnOverwrite, 'Create surface from index')
         Publisher.subscribe(self.OnFoldSurface, 'Fold surface task')
         Publisher.subscribe(self.OnFoldExport, 'Fold export task')
+        Publisher.subscribe(self.SetNavigationMode, "Set navigation mode")
 
     def OnOverwrite(self, pubsub_evt):
         self.overwrite = pubsub_evt.data['options']['overwrite']
@@ -315,6 +319,37 @@ class UpperTaskPanel(wx.Panel):
         else:
             self.SetStateProjectClose()
 
+    def SetNavigationMode(self, pubsub_evt):
+        self.navigation_mode_status = status = pubsub_evt.data
+        name = _("Navigation system")
+        panel = navigator.TaskPanel
+        if status and (self.fold_panel.GetCount()<=4):
+            # Create panel
+            item = self.fold_panel.AddFoldPanel("%d. %s"%(5, name),
+                                                collapsed=True,
+                                                foldIcons=self.image_list)
+            style = self.fold_panel.GetCaptionStyle(item)
+            col = style.GetFirstColour()
+
+            # Add panel to FoldPanel
+            self.fold_panel.AddFoldPanelWindow(item,
+                                               panel(item),
+                                               #Spacing=0,
+                                               leftSpacing=0,
+                                               rightSpacing=0)
+            self.enable_items.append(item)
+            if not self.fold_panel.GetFoldPanel(2).IsEnabled():
+                item.Disable()
+
+        elif status and (self.fold_panel.GetCount()>4):
+            self.fold_panel.GetFoldPanel(4).Show()
+
+        else:
+            self.fold_panel.GetFoldPanel(4).Hide()
+        self.sizer.Layout()
+
+
+
     def SetStateProjectClose(self):
         self.fold_panel.Expand(self.fold_panel.GetFoldPanel(0))
         for item in self.enable_items:
