@@ -17,21 +17,24 @@
 #    detalhes.
 #--------------------------------------------------------------------------
 import sys
+import os
 
 import wx
 import wx.lib.agw.fourwaysplitter as fws
 from wx.lib.pubsub import pub as Publisher
 
-import data.viewer_slice as slice_viewer
-import data.viewer_volume as volume_viewer
-import project
-import widgets.slice_menu as slice_menu_
+import invesalius.data.viewer_slice as slice_viewer
+import invesalius.data.viewer_volume as volume_viewer
+import invesalius.project as project
+import invesalius.gui.widgets.slice_menu as slice_menu_
 
-from gui.widgets.clut_raycasting import CLUTRaycastingWidget, \
+
+from invesalius.gui.widgets.clut_raycasting import CLUTRaycastingWidget, \
         EVT_CLUT_POINT_RELEASE, EVT_CLUT_CURVE_SELECT, \
         EVT_CLUT_CURVE_WL_CHANGE
 
-from constants import ID_TO_BMP
+from invesalius.constants import ID_TO_BMP
+import invesalius.constants as const
 
 class Panel(wx.Panel):
     def __init__(self, parent):
@@ -299,9 +302,9 @@ class VolumeInteraction(wx.Panel):
 import wx.lib.platebtn as pbtn
 import wx.lib.buttons as btn
 import wx.lib.pubsub as ps
+import wx.lib.colourselect as csel
 
-import constants as const
-import widgets.colourselect as csel
+import invesalius.constants as const
 
 [BUTTON_RAYCASTING, BUTTON_VIEW, BUTTON_SLICE_PLANE, BUTTON_3D_STEREO] = [wx.NewId() for num in xrange(4)]
 RAYCASTING_TOOLS = wx.NewId()
@@ -333,14 +336,14 @@ class VolumeToolPanel(wx.Panel):
         wx.Panel.__init__(self, parent)
 
         # VOLUME RAYCASTING BUTTON
-        BMP_RAYCASTING = wx.Bitmap("../icons/volume_raycasting.png",
+        BMP_RAYCASTING = wx.Bitmap(os.path.join(const.ICON_DIR, "volume_raycasting.png"),
                                     wx.BITMAP_TYPE_PNG)
 
-        BMP_SLICE_PLANE = wx.Bitmap("../icons/slice_plane.png",
+        BMP_SLICE_PLANE = wx.Bitmap(os.path.join(const.ICON_DIR, "slice_plane.png"),
                                     wx.BITMAP_TYPE_PNG)
 
 
-        BMP_3D_STEREO = wx.Bitmap("../icons/3D_glasses.png",
+        BMP_3D_STEREO = wx.Bitmap(os.path.join(const.ICON_DIR, "3D_glasses.png"),
                                     wx.BITMAP_TYPE_PNG)
 
 
