@@ -21,6 +21,7 @@
 # -*- coding: UTF-8 -*-
 
 #TODO: To create a beautiful API
+import sys
 import time
 import tempfile
 
@@ -31,12 +32,20 @@ from vtk.util import  numpy_support
 from vtk.wx.wxVTKRenderWindowInteractor import wxVTKRenderWindowInteractor
 from wx.lib.pubsub import pub as Publisher
 
-import constants as const
-from reader import dicom_reader
-import data.vtk_utils as vtku
-import utils
+import invesalius.constants as const
+import invesalius.reader.dicom_reader as dicom_reader
+import invesalius.data.vtk_utils as vtku
+import invesalius.utils as utils
 import vtkgdcm
 
+if sys.platform == 'win32':
+    try:
+        import win32api
+        _has_win32api = True
+    except ImportError:
+        _has_win32api = False
+else:
+    _has_win32api = False
 
 NROWS = 3
 NCOLS = 6
@@ -837,7 +846,10 @@ class SingleImagePreview(wx.Panel):
         self.text_acquisition.SetValue(value)
 
         rdicom = vtkgdcm.vtkGDCMImageReader()
-        rdicom.SetFileName(dicom.image.file)
+        if _has_win32api:
+            rdicom.SetFileName(win32api.GetShortPathName(dicom.image.file).encode(const.FS_ENCODE))
+        else:
+            rdicom.SetFileName(dicom.image.file)
         rdicom.Update()
 
         # ADJUST CONTRAST
