@@ -31,17 +31,17 @@ import wx.lib.popupctl as pc
 
 from wx.lib.agw.aui.auibar import AuiToolBar, AUI_TB_PLAIN_BACKGROUND
 
-import constants as const
-import default_tasks as tasks
-import default_viewers as viewers
-import gui.dialogs as dlg
-import import_panel as imp
-import import_network_panel as imp_net
-import project as prj
-import session as ses
-import utils
-import preferences
-
+import invesalius.constants as const
+import invesalius.gui.default_tasks as tasks
+import invesalius.gui.default_viewers as viewers
+import invesalius.gui.dialogs as dlg
+import invesalius.gui.import_panel as imp
+import invesalius.gui.import_bitmap_panel as imp_bmp
+import invesalius.gui.import_network_panel as imp_net
+import invesalius.project as prj
+import invesalius.session as ses
+import invesalius.utils as utils
+import invesalius.gui.preferences as preferences
 # Layout tools' IDs - this is used only locally, therefore doesn't
 # need to be defined in constants.py
 VIEW_TOOLS = [ID_LAYOUT, ID_TEXT] =\
@@ -84,6 +84,7 @@ class Frame(wx.Frame):
 
         self.mw = None
 
+
         if sys.platform != 'darwin':
             self.Maximize()
 
@@ -93,9 +94,16 @@ class Frame(wx.Frame):
         self.SetSize(self.GetSize())
         #self.SetSize(wx.Size(1024, 748))
 
+        self._show_navigator_message = True
+
+        #to control check and unckeck of menu view -> interpolated_slices
+        main_menu = MenuBar(self)
+
+        self.actived_interpolated_slices = main_menu.view_menu
+        self.actived_navigation_mode = main_menu.mode_menu
 
         # Set menus, status and task bar
-        self.SetMenuBar(MenuBar(self))
+        self.SetMenuBar(main_menu)
         self.SetStatusBar(StatusBar(self))
 
         # Set TaskBarIcon
@@ -126,6 +134,7 @@ class Frame(wx.Frame):
         sub(self._ShowImportPanel, 'Show import panel in frame')
         #sub(self._ShowHelpMessage, 'Show help message')
         sub(self._ShowImportNetwork, 'Show retrieve dicom panel')
+        sub(self._ShowImportBitmap, 'Show import bitmap panel in frame')
         sub(self._ShowTask, 'Show task panel')
         sub(self._UpdateAUI, 'Update AUI')
         sub(self._Exit, 'Exit')
@@ -166,12 +175,17 @@ class Frame(wx.Frame):
                           Hide().Layer(1).MaximizeButton(True).
                           Name("Data").Position(1))
 
-        # This is the DICOM import panel. When the two panels above
-        # are shown, this should be hiden
+        # This is the DICOM import panel. When the two panels above as dicom        # are shown, this should be hiden
         caption = _("Preview medical data to be reconstructed")
         aui_manager.AddPane(imp.Panel(self), wx.aui.AuiPaneInfo().
-                          Name("Import").Centre().Hide().
-                          MaximizeButton(True).Floatable(True).
+                          Name("Import").CloseButton(False).Centre().Hide().
+                          MaximizeButton(False).Floatable(True).
+                          Caption(caption).CaptionVisible(True))
+
+        caption = _("Preview bitmap to be reconstructed")
+        aui_manager.AddPane(imp_bmp.Panel(self), wx.aui.AuiPaneInfo().
+                          Name("ImportBMP").CloseButton(False).Centre().Hide().
+                          MaximizeButton(False).Floatable(True).
                           Caption(caption).CaptionVisible(True))
 
         ncaption = _("Retrieve DICOM from PACS")
@@ -298,6 +312,9 @@ class Frame(wx.Frame):
         Publisher.sendMessage("Set layout button full")
         aui_manager = self.aui_manager
         aui_manager.GetPane("Import").Show(0)
+        
+        aui_manager.GetPane("ImportBMP").Show(0)
+
         aui_manager.GetPane("Data").Show(1)
         aui_manager.GetPane("Tasks").Show(1)
         aui_manager.Update()
@@ -314,6 +331,18 @@ class Frame(wx.Frame):
         aui_manager.GetPane("Import").Show(0)
         aui_manager.Update()
 
+    def _ShowImportBitmap(self, evt_pubsub):
+        """
+        Show viewers and task, hide import panel.
+        """
+        Publisher.sendMessage("Set layout button full")
+        aui_manager = self.aui_manager
+        aui_manager.GetPane("ImportBMP").Show(1)
+        aui_manager.GetPane("Data").Show(0)
+        aui_manager.GetPane("Tasks").Show(0)
+        aui_manager.GetPane("Import").Show(0)
+        aui_manager.Update()
+
     def _ShowHelpMessage(self, evt_pubsub):
         aui_manager = self.aui_manager
         pos = aui_manager.GetPane("Data").window.GetScreenPosition()
@@ -324,8 +353,7 @@ class Frame(wx.Frame):
 
     def _ShowImportPanel(self, evt_pubsub):
         """
-        Show only DICOM import panel.
-        """
+        Show only DICOM import panel. as dicom        """
         Publisher.sendMessage("Set layout button data only")
         aui_manager = self.aui_manager
         aui_manager.GetPane("Import").Show(1)
@@ -354,6 +382,7 @@ class Frame(wx.Frame):
         Close all project data.
         """
         Publisher.sendMessage('Close Project')
+        Publisher.sendMessage('Disconnect tracker')
         s = ses.Session()
         if not s.IsOpen() or not s.project_path:
             Publisher.sendMessage('Exit')
@@ -370,7 +399,13 @@ class Frame(wx.Frame):
         elif id == const.ID_PROJECT_OPEN:
             self.ShowOpenProject()
         elif id == const.ID_ANALYZE_IMPORT:
-            self.ShowAnalyzeImporter()
+            self.ShowImportOtherFiles(id)
+        elif id == const.ID_NIFTI_IMPORT:
+            self.ShowImportOtherFiles(id)
+        elif id == const.ID_PARREC_IMPORT:
+            self.ShowImportOtherFiles(id)
+        elif id == const.ID_TIFF_JPG_PNG:
+            self.ShowBitmapImporter()
         elif id == const.ID_PROJECT_SAVE:
             session = ses.Session()
             if session.temp_item:
@@ -411,6 +446,64 @@ class Frame(wx.Frame):
         elif id == const.ID_CLEAN_MASK:
             self.OnCleanMask()
 
+        elif id == const.ID_REORIENT_IMG:
+            self.OnReorientImg()
+
+        elif id == const.ID_THRESHOLD_SEGMENTATION:
+            Publisher.sendMessage("Show panel", const.ID_THRESHOLD_SEGMENTATION)
+            Publisher.sendMessage('Disable actual style')
+            Publisher.sendMessage('Enable style', const.STATE_DEFAULT)
+
+        elif id == const.ID_MANUAL_SEGMENTATION:
+            Publisher.sendMessage("Show panel", const.ID_MANUAL_SEGMENTATION)
+            Publisher.sendMessage('Disable actual style')
+            Publisher.sendMessage('Enable style', const.SLICE_STATE_EDITOR)
+
+        elif id == const.ID_WATERSHED_SEGMENTATION:
+            Publisher.sendMessage("Show panel", const.ID_WATERSHED_SEGMENTATION)
+            Publisher.sendMessage('Disable actual style')
+            Publisher.sendMessage('Enable style', const.SLICE_STATE_WATERSHED)
+
+        elif id == const.ID_FLOODFILL_MASK:
+            self.OnFillHolesManually()
+
+        elif id == const.ID_FILL_HOLE_AUTO:
+            self.OnFillHolesAutomatically()
+
+        elif id == const.ID_REMOVE_MASK_PART:
+            self.OnRemoveMaskParts()
+
+        elif id == const.ID_SELECT_MASK_PART:
+            self.OnSelectMaskParts()
+
+        elif id == const.ID_FLOODFILL_SEGMENTATION:
+            self.OnFFillSegmentation()
+
+        elif id == const.ID_VIEW_INTERPOLATED:
+            st = self.actived_interpolated_slices.IsChecked(const.ID_VIEW_INTERPOLATED)
+            if st:
+                self.OnInterpolatedSlices(True)
+            else:
+                self.OnInterpolatedSlices(False)
+
+        elif id == const.ID_MODE_NAVIGATION:
+            st = self.actived_navigation_mode.IsChecked(const.ID_MODE_NAVIGATION)
+            self.OnNavigationMode(st)
+
+        elif id == const.ID_CROP_MASK:
+            self.OnCropMask()
+
+    def OnInterpolatedSlices(self, status):
+        Publisher.sendMessage('Set interpolated slices', status)
+
+    def OnNavigationMode(self, status):
+        if status and self._show_navigator_message and sys.platform != 'win32':
+            wx.MessageBox(_('Currently the Navigation mode is only working on Windows'), 'Info', wx.OK | wx.ICON_INFORMATION)
+            self._show_navigator_message = False
+        Publisher.sendMessage('Set navigation mode', status)
+        if not status:
+            Publisher.sendMessage('Remove sensors ID')
+
     def OnSize(self, evt):
         """
         Refresh GUI when frame is resized.
@@ -444,9 +537,13 @@ class Frame(wx.Frame):
             ses.Session().rendering = values[const.RENDERING]
             ses.Session().surface_interpolation = values[const.SURFACE_INTERPOLATION]
             ses.Session().language = values[const.LANGUAGE]
+            ses.Session().slice_interpolation = values[const.SLICE_INTERPOLATION]
 
             Publisher.sendMessage('Remove Volume')
             Publisher.sendMessage('Reset Reaycasting')
+            Publisher.sendMessage('Update Slice Interpolation')
+            Publisher.sendMessage('Update Slice Interpolation MenuBar')
+            Publisher.sendMessage('Update Navigation Mode MenuBar')
             Publisher.sendMessage('Update Surface Interpolation')
 
     def ShowAbout(self):
@@ -465,18 +562,28 @@ class Frame(wx.Frame):
         """
         Show getting started window.
         """
+        if ses.Session().language == 'pt_BR':
+            user_guide = "user_guide_pt_BR.pdf"
+        else:
+            user_guide = "user_guide_en.pdf"
+
         path = os.path.join(const.DOC_DIR,
-                            "user_guide_pt_BR.pdf")
+                            user_guide)
         if sys.platform == 'darwin':
             path = r'file://' + path
         webbrowser.open(path)
 
     def ShowImportDicomPanel(self):
         """
-        Show import DICOM panel.
-        """
+        Show import DICOM panel. as dicom        """
         Publisher.sendMessage('Show import directory dialog')
 
+    def ShowImportOtherFiles(self, id_file):
+        """
+        Show import Analyze, NiFTI1 or PAR/REC dialog.
+        """
+        Publisher.sendMessage('Show import other files dialog', id_file)
+
     def ShowRetrieveDicomPanel(self):
         Publisher.sendMessage('Show retrieve dicom panel')
 
@@ -492,11 +599,11 @@ class Frame(wx.Frame):
         """
         Publisher.sendMessage('Show save dialog', True)
 
-    def ShowAnalyzeImporter(self):
+    def ShowBitmapImporter(self):
         """
-        Show save as dialog.
+        Tiff, BMP, JPEG and PNG
         """
-        Publisher.sendMessage('Show analyze dialog', True)
+        Publisher.sendMessage('Show bitmap dialog', True)
 
     def FlipVolume(self, axis):
         Publisher.sendMessage('Flip volume', axis)
@@ -520,6 +627,33 @@ class Frame(wx.Frame):
         Publisher.sendMessage('Clean current mask')
         Publisher.sendMessage('Reload actual slice')
 
+    def OnReorientImg(self):
+        Publisher.sendMessage('Enable style', const.SLICE_STATE_REORIENT)
+        rdlg = dlg.ReorientImageDialog()
+        rdlg.Show()
+
+    def OnFillHolesManually(self):
+        Publisher.sendMessage('Enable style', const.SLICE_STATE_MASK_FFILL)
+
+    def OnFillHolesAutomatically(self):
+        fdlg = dlg.FillHolesAutoDialog(_(u"Fill holes automatically"))
+        fdlg.Show()
+
+    def OnRemoveMaskParts(self):
+        Publisher.sendMessage('Enable style', const.SLICE_STATE_REMOVE_MASK_PARTS)
+
+    def OnSelectMaskParts(self):
+        Publisher.sendMessage('Enable style', const.SLICE_STATE_SELECT_MASK_PARTS)
+
+    def OnFFillSegmentation(self):
+        Publisher.sendMessage('Enable style', const.SLICE_STATE_FFILL_SEGMENTATION)
+
+    def OnInterpolatedSlices(self, status):
+        Publisher.sendMessage('Set interpolated slices', status)
+    
+    def OnCropMask(self):
+        Publisher.sendMessage('Enable style', const.SLICE_STATE_CROP_MASK)
+
 # ------------------------------------------------------------------
 # ------------------------------------------------------------------
 # ------------------------------------------------------------------
@@ -538,7 +672,24 @@ class MenuBar(wx.MenuBar):
         # not. Eg. save should only be available if a project is open
         self.enable_items = [const.ID_PROJECT_SAVE,
                              const.ID_PROJECT_SAVE_AS,
-                             const.ID_PROJECT_CLOSE]
+                             const.ID_PROJECT_CLOSE,
+                             const.ID_REORIENT_IMG,
+                             const.ID_FLOODFILL_MASK,
+                             const.ID_FILL_HOLE_AUTO,
+                             const.ID_REMOVE_MASK_PART,
+                             const.ID_SELECT_MASK_PART,
+                             const.ID_FLOODFILL_SEGMENTATION,
+                             const.ID_FLIP_X,
+                             const.ID_FLIP_Y,
+                             const.ID_FLIP_Z,
+                             const.ID_SWAP_XY,
+                             const.ID_SWAP_XZ,
+                             const.ID_SWAP_YZ,
+                             const.ID_THRESHOLD_SEGMENTATION,
+                             const.ID_MANUAL_SEGMENTATION,
+                             const.ID_WATERSHED_SEGMENTATION,
+                             const.ID_THRESHOLD_SEGMENTATION,
+                             const.ID_FLOODFILL_SEGMENTATION,]
         self.__init_items()
         self.__bind_events()
 
@@ -556,10 +707,13 @@ class MenuBar(wx.MenuBar):
         sub(self.OnEnableState, "Enable state project")
         sub(self.OnEnableUndo, "Enable undo")
         sub(self.OnEnableRedo, "Enable redo")
+        sub(self.OnEnableNavigation, "Navigation Status")
 
         sub(self.OnAddMask, "Add mask")
         sub(self.OnRemoveMasks, "Remove masks")
         sub(self.OnShowMask, "Show mask")
+        sub(self.OnUpdateSliceInterpolation, "Update Slice Interpolation MenuBar")
+        sub(self.OnUpdateNavigationMode, "Update Navigation Mode MenuBar")
 
         self.num_masks = 0
 
@@ -571,7 +725,10 @@ class MenuBar(wx.MenuBar):
 
         #Import Others Files
         others_file_menu = wx.Menu()
-        others_file_menu.Append(const.ID_ANALYZE_IMPORT, "Analyze")
+        others_file_menu.Append(const.ID_ANALYZE_IMPORT, _("Analyze 7.5"))
+        others_file_menu.Append(const.ID_NIFTI_IMPORT, _("NIfTI 1"))
+        others_file_menu.Append(const.ID_PARREC_IMPORT, _("PAR/REC"))
+        others_file_menu.Append(const.ID_TIFF_JPG_PNG, u"TIFF,BMP,JPG or PNG (\xb5CT)")
 
         # FILE
         file_menu = wx.Menu()
@@ -593,26 +750,7 @@ class MenuBar(wx.MenuBar):
         #file_menu.AppendSeparator()
         app(const.ID_EXIT, _("Exit\tCtrl+Q"))
 
-
-        ############################### EDIT###############################
-        # Flip
-        #flip_menu = wx.Menu()
-        #app = flip_menu.Append
-        #app(const.ID_FLIP_X, _("R <-> L"))
-        #app(const.ID_FLIP_Y, _("A <-> P"))
-        #app(const.ID_FLIP_Z, _("T <-> B"))
-
-        #swap_axes_menu = wx.Menu()
-        #app = swap_axes_menu.Append
-        #app(const.ID_SWAP_XY, _("R-L <-> A-P"))
-        #app(const.ID_SWAP_XZ, _("R-L <-> T-B"))
-        #app(const.ID_SWAP_YZ, _("A-P <-> T-B"))
-
         file_edit = wx.Menu()
-        #file_edit.AppendMenu(wx.NewId(), _('Flip'), flip_menu)
-        #file_edit.AppendMenu(wx.NewId(), _('Swap axes'), swap_axes_menu)
-
-
         d = const.ICON_DIR
         if not(sys.platform == 'darwin'):
             # Bitmaps for show/hide task panel item
@@ -648,10 +786,71 @@ class MenuBar(wx.MenuBar):
         self.clean_mask_menu = mask_menu.Append(const.ID_CLEAN_MASK, _(u"Clean Mask\tCtrl+Shift+A"))
         self.clean_mask_menu.Enable(False)
 
+        mask_menu.AppendSeparator()
+
+        self.fill_hole_mask_menu = mask_menu.Append(const.ID_FLOODFILL_MASK, _(u"Fill holes manually"))
+        self.fill_hole_mask_menu.Enable(False)
+
+        self.fill_hole_auto_menu = mask_menu.Append(const.ID_FILL_HOLE_AUTO, _(u"Fill holes automatically"))
+        self.fill_hole_mask_menu.Enable(False)
+
+        mask_menu.AppendSeparator()
+
+        self.remove_mask_part_menu = mask_menu.Append(const.ID_REMOVE_MASK_PART, _(u"Remove parts"))
+        self.remove_mask_part_menu.Enable(False)
+
+        self.select_mask_part_menu = mask_menu.Append(const.ID_SELECT_MASK_PART, _(u"Select parts"))
+        self.select_mask_part_menu.Enable(False)
+
+        mask_menu.AppendSeparator()
+
+        self.crop_mask_menu = mask_menu.Append(const.ID_CROP_MASK, _("Crop"))
+        self.crop_mask_menu.Enable(False)
+
+        # Segmentation Menu
+        segmentation_menu = wx.Menu()
+        self.threshold_segmentation = segmentation_menu.Append(const.ID_THRESHOLD_SEGMENTATION, _(u"Threshold"))
+        self.manual_segmentation = segmentation_menu.Append(const.ID_MANUAL_SEGMENTATION, _(u"Manual segmentation"))
+        self.watershed_segmentation = segmentation_menu.Append(const.ID_WATERSHED_SEGMENTATION, _(u"Watershed"))
+        self.ffill_segmentation = segmentation_menu.Append(const.ID_FLOODFILL_SEGMENTATION, _(u"Region growing"))
+        self.ffill_segmentation.Enable(False)
+
+        # Image menu
+        image_menu = wx.Menu()
+
+        # Flip
+        flip_menu = wx.Menu()
+        flip_menu.Append(const.ID_FLIP_X, _("Right - Left")).Enable(False)
+        flip_menu.Append(const.ID_FLIP_Y, _("Anterior - Posterior")).Enable(False)
+        flip_menu.Append(const.ID_FLIP_Z, _("Top - Bottom")).Enable(False)
+
+        swap_axes_menu = wx.Menu()
+        swap_axes_menu.Append(const.ID_SWAP_XY, _("From Right-Left to Anterior-Posterior")).Enable(False)
+        swap_axes_menu.Append(const.ID_SWAP_XZ, _("From Right-Left to Top-Bottom")).Enable(False)
+        swap_axes_menu.Append(const.ID_SWAP_YZ, _("From Anterior-Posterior to Top-Bottom")).Enable(False)
+
+        image_menu.AppendMenu(wx.NewId(), _('Flip'), flip_menu)
+        image_menu.AppendMenu(wx.NewId(), _('Swap axes'), swap_axes_menu)
+
+        reorient_menu = image_menu.Append(const.ID_REORIENT_IMG, _(u'Reorient image\tCtrl+Shift+R'))
+
+        reorient_menu.Enable(False)
+        tools_menu.AppendMenu(-1, _(u'Image'), image_menu)
         tools_menu.AppendMenu(-1,  _(u"Mask"), mask_menu)
+        tools_menu.AppendMenu(-1, _("Segmentation"), segmentation_menu)
 
 
-        # VIEW
+        #View
+
+        self.view_menu = view_menu = wx.Menu()
+        view_menu.Append(const.ID_VIEW_INTERPOLATED, _(u'Interpolated slices'), "", wx.ITEM_CHECK)
+
+
+        v = self.SliceInterpolationStatus()
+        self.view_menu.Check(const.ID_VIEW_INTERPOLATED, v)
+
+        self.actived_interpolated_slices = self.view_menu
+
         #view_tool_menu = wx.Menu()
         #app = view_tool_menu.Append
         #app(const.ID_TOOL_PROJECT, "Project Toolbar")
@@ -683,6 +882,15 @@ class MenuBar(wx.MenuBar):
         options_menu = wx.Menu()
         options_menu.Append(const.ID_PREFERENCES, _("Preferences..."))
 
+        #Mode
+        self.mode_menu = mode_menu = wx.Menu()
+        mode_menu.Append(const.ID_MODE_NAVIGATION, _(u'Navigation mode'), "", wx.ITEM_CHECK)
+
+        v = self.NavigationModeStatus()
+        self.mode_menu.Check(const.ID_MODE_NAVIGATION, v)
+
+        self.actived_navigation_mode = self.mode_menu
+
         # HELP
         help_menu = wx.Menu()
         help_menu.Append(const.ID_START, _("Getting started..."))
@@ -698,12 +906,41 @@ class MenuBar(wx.MenuBar):
         # Add all menus to menubar
         self.Append(file_menu, _("File"))
         self.Append(file_edit, _("Edit"))
+        self.Append(view_menu, _(u"View"))
         self.Append(tools_menu, _(u"Tools"))
-        #self.Append(view_menu, "View")
         #self.Append(tools_menu, "Tools")
         self.Append(options_menu, _("Options"))
+        self.Append(mode_menu, _("Mode"))
         self.Append(help_menu, _("Help"))
 
+
+    def SliceInterpolationStatus(self):
+        
+        status = int(ses.Session().slice_interpolation)
+        
+        if status == 0:
+            v = True
+        else:
+            v = False
+
+        return v
+
+    def NavigationModeStatus(self):
+        status = int(ses.Session().mode)
+
+        if status == 1:
+            return True
+        else:
+            return False
+
+    def OnUpdateSliceInterpolation(self, pubsub_evt):
+        v = self.SliceInterpolationStatus()
+        self.view_menu.Check(const.ID_VIEW_INTERPOLATED, v)
+
+    def OnUpdateNavigationMode(self, pubsub_evt):
+        v = self.NavigationModeStatus()
+        self.mode_menu.Check(const.ID_MODE_NAVIGATION, v)
+
     def OnEnableState(self, pubsub_evt):
         """
         Based on given state, enables or disables menu items which
@@ -743,6 +980,17 @@ class MenuBar(wx.MenuBar):
         else:
             self.FindItemById(wx.ID_REDO).Enable(False)
 
+    def OnEnableNavigation(self, pubsub_evt):
+        """
+        Disable mode menu when navigation is on.
+        :param pubsub_evt: Navigation status
+        """
+        value = pubsub_evt.data
+        if value:
+            self.FindItemById(const.ID_MODE_NAVIGATION).Enable(False)
+        else:
+            self.FindItemById(const.ID_MODE_NAVIGATION).Enable(True)
+
     def OnAddMask(self, pubsub_evt):
         self.num_masks += 1
         self.bool_op_menu.Enable(self.num_masks >= 2)
@@ -754,6 +1002,7 @@ class MenuBar(wx.MenuBar):
     def OnShowMask(self, pubsub_evt):
         index, value = pubsub_evt.data
         self.clean_mask_menu.Enable(value)
+        self.crop_mask_menu.Enable(value)
 
 
 # ------------------------------------------------------------------
@@ -887,8 +1136,7 @@ class TaskBarIcon(wx.TaskBarIcon):
 
 class ProjectToolBar(AuiToolBar):
     """
-    Toolbar related to general project operations, including: import,
-    open, save and saveas, among others.
+    Toolbar related to general invesalius.project operations, including: import, as project    open, save and saveas, among others.
     """
     def __init__(self, parent):
         style = AUI_TB_PLAIN_BACKGROUND
@@ -1059,6 +1307,7 @@ class ObjectToolBar(AuiToolBar):
         sub(self._UntoggleAllItems, 'Untoggle object toolbar items')
         sub(self._ToggleLinearMeasure, "Set tool linear measure")
         sub(self._ToggleAngularMeasure, "Set tool angular measure")
+        sub(self.ToggleItem, 'Toggle toolbar item')
 
     def __bind_events_wx(self):
         """
@@ -1244,6 +1493,12 @@ class ObjectToolBar(AuiToolBar):
                 self.ToggleTool(item, False)
         evt.Skip()
 
+    def ToggleItem(self, evt):
+        _id, value = evt.data
+        if _id in self.enable_items:
+            self.ToggleTool(_id, value)
+            self.Refresh()
+
     def SetStateProjectClose(self):
         """
         Disable menu items (e.g. zoom) when project is closed.
@@ -1278,7 +1533,7 @@ class SliceToolBar(AuiToolBar):
 
         self.parent = parent
         self.enable_items = [const.SLICE_STATE_SCROLL,
-                             const.SLICE_STATE_CROSS]
+                             const.SLICE_STATE_CROSS,]
         self.__init_items()
         self.__bind_events()
         self.__bind_events_wx()
@@ -1323,6 +1578,8 @@ class SliceToolBar(AuiToolBar):
         sub = Publisher.subscribe
         sub(self._EnableState, "Enable state project")
         sub(self._UntoggleAllItems, 'Untoggle slice toolbar items')
+        sub(self.OnToggle, 'Toggle Cross')
+        sub(self.ToggleItem, 'Toggle toolbar item')
 
     def __bind_events_wx(self):
         """
@@ -1361,8 +1618,14 @@ class SliceToolBar(AuiToolBar):
         Update status of other items on toolbar (only one item
         should be toggle each time).
         """
-        id = evt.GetId()
-        evt.Skip()
+        if hasattr(evt, 'data'):
+            id = evt.data
+            if not self.GetToolToggled(id):
+                self.ToggleTool(id, True)
+                self.Refresh()
+        else:
+            id = evt.GetId()
+            evt.Skip()
 
         state = self.GetToolToggled(id)
 
@@ -1382,6 +1645,11 @@ class SliceToolBar(AuiToolBar):
         ##print ">>>", self.sst.IsToggled()
         #print ">>>", self.sst.GetState()
 
+    def ToggleItem(self, evt):
+        _id, value = evt.data
+        if _id in self.enable_items:
+            self.ToggleTool(_id, value)
+            self.Refresh()
 
     def SetStateProjectClose(self):
         """
