@@ -21,10 +21,10 @@ import wx.gizmos as gizmos
 from wx.lib.pubsub import pub as Publisher
 import wx.lib.splitter as spl
 
-import constants as const
-import gui.dialogs as dlg
-import dicom_preview_panel as dpp
-import reader.dicom_grouper as dcm
+import invesalius.constants as const
+import invesalius.gui.dialogs as dlg
+import invesalius.gui.dicom_preview_panel as dpp
+import invesalius.reader.dicom_grouper as dcm
 
 myEVT_SELECT_SERIE = wx.NewEventType()
 EVT_SELECT_SERIE = wx.PyEventBinder(myEVT_SELECT_SERIE, 1)
