@@ -18,22 +18,23 @@
 #    detalhes.
 #--------------------------------------------------------------------------
 import sys
+import os
 
 import wx
 import wx.lib.hyperlink as hl
 import wx.lib.platebtn as pbtn
+import wx.lib.foldpanelbar as fpb
+import wx.lib.colourselect as csel
 from wx.lib.pubsub import pub as Publisher
 
-import data.mask as mask
-import data.slice_ as slice_
-import constants as const
-import gui.dialogs as dlg
-import gui.widgets.gradient as grad
-import gui.widgets.foldpanelbar as fpb
-import widgets.colourselect as csel
+import invesalius.data.mask as mask
+import invesalius.data.slice_ as slice_
+import invesalius.constants as const
+import invesalius.gui.dialogs as dlg
+import invesalius.gui.widgets.gradient as grad
 
-from project import Project
-import session as ses
+from invesalius.project import Project
+import invesalius.session as ses
 
 BTN_NEW = wx.NewId()
 
@@ -70,7 +71,7 @@ class InnerTaskPanel(wx.Panel):
         self.SetAutoLayout(1)
 
         # Image(s) for buttons
-        BMP_ADD = wx.Bitmap("../icons/object_add.png", wx.BITMAP_TYPE_PNG)
+        BMP_ADD = wx.Bitmap(os.path.join(const.ICON_DIR, "object_add.png"), wx.BITMAP_TYPE_PNG)
         #BMP_ADD.SetWidth(25)
         #BMP_ADD.SetHeight(25)
 
@@ -267,7 +268,7 @@ class InnerFoldPanel(wx.Panel):
         self.mask_prop_panel = MaskProperties(item)
 
         fold_panel.ApplyCaptionStyle(item, style)
-        fold_panel.AddFoldPanelWindow(item, self.mask_prop_panel, Spacing= 0,
+        fold_panel.AddFoldPanelWindow(item, self.mask_prop_panel, spacing= 0,
                                       leftSpacing=0, rightSpacing=0)
 
         # Fold 2 - Advanced edition tools
@@ -275,7 +276,7 @@ class InnerFoldPanel(wx.Panel):
         etw = EditionTools(item)
 
         fold_panel.ApplyCaptionStyle(item, style)
-        fold_panel.AddFoldPanelWindow(item, etw, Spacing= 0,
+        fold_panel.AddFoldPanelWindow(item, etw, spacing= 0,
                                       leftSpacing=0, rightSpacing=0)
         self.__id_editor = item.GetId()
         self.last_panel_opened = None
@@ -285,7 +286,7 @@ class InnerFoldPanel(wx.Panel):
         wtw = WatershedTool(item)
 
         fold_panel.ApplyCaptionStyle(item, style)
-        fold_panel.AddFoldPanelWindow(item, wtw, Spacing= 0,
+        fold_panel.AddFoldPanelWindow(item, wtw, spacing= 0,
                                       leftSpacing=0, rightSpacing=0)
         self.__id_watershed = item.GetId()
 
@@ -341,6 +342,7 @@ class InnerFoldPanel(wx.Panel):
         Publisher.subscribe(self.OnRetrieveStyle, 'Retrieve task slice style')
         Publisher.subscribe(self.OnDisableStyle, 'Disable task slice style')
         Publisher.subscribe(self.OnCloseProject, 'Close project data')
+        Publisher.subscribe(self.OnColapsePanel, 'Show panel')
 
     def OnFoldPressCaption(self, evt):
         id = evt.GetTag().GetId()
@@ -387,6 +389,19 @@ class InnerFoldPanel(wx.Panel):
     def OnCloseProject(self, pubsub_evt):
         self.fold_panel.Expand(self.fold_panel.GetFoldPanel(0))
 
+    def OnColapsePanel(self, pubsub_evt):
+        panel_seg_id = {
+            const.ID_THRESHOLD_SEGMENTATION: 0,
+            const.ID_MANUAL_SEGMENTATION: 1,
+            const.ID_WATERSHED_SEGMENTATION: 2
+        }
+
+        try:
+            _id = panel_seg_id[pubsub_evt.data]
+            self.fold_panel.Expand(self.fold_panel.GetFoldPanel(_id))
+        except KeyError:
+            pass
+
     def GetMaskSelected(self):
         x= self.mask_prop_panel.GetMaskSelected()
         return self.mask_prop_panel.GetMaskSelected()
@@ -406,7 +421,7 @@ class MaskProperties(wx.Panel):
         self.combo_mask_name = combo_mask_name
 
         # Mask colour
-        button_colour= csel.ColourSelect(self, 111,colour=(0,255,0),size=(-1,22))
+        button_colour= csel.ColourSelect(self, 111,colour=(0,255,0),size=(22,-1))
         self.button_colour = button_colour
 
         # Sizer which represents the first line
@@ -524,6 +539,7 @@ class MaskProperties(wx.Panel):
         self.bind_evt_gradient = False
         self.gradient.SetMinValue(thresh_min)
         self.gradient.SetMaxValue(thresh_max)
+        
         self.bind_evt_gradient = True
         thresh = (thresh_min, thresh_max)
         if thresh in Project().threshold_modes.values():
@@ -561,10 +577,10 @@ class MaskProperties(wx.Panel):
         mask_thresh = evt_pubsub.data[2]
         mask_colour = [int(c*255) for c in evt_pubsub.data[3]]
         index = self.combo_mask_name.Append(mask_name)
-        self.combo_mask_name.SetSelection(index)
-        self.button_colour.SetColour(mask_colour)
-        self.gradient.SetColour(mask_colour)
-        self.combo_mask_name.SetSelection(index)
+        #  self.combo_mask_name.SetSelection(index)
+        #  self.button_colour.SetColour(mask_colour)
+        #  self.gradient.SetColour(mask_colour)
+        #  self.combo_mask_name.SetSelection(index)
 
     def GetMaskSelected(self):
         x = self.combo_mask_name.GetSelection()
@@ -650,11 +666,11 @@ class EditionTools(wx.Panel):
         ## LINE 2
         menu = wx.Menu()
 
-        CIRCLE_BMP = wx.Bitmap("../icons/brush_circle.jpg", wx.BITMAP_TYPE_JPEG)
+        CIRCLE_BMP = wx.Bitmap(os.path.join(const.ICON_DIR, "brush_circle.jpg"), wx.BITMAP_TYPE_JPEG)
         item = wx.MenuItem(menu, MENU_BRUSH_CIRCLE, _("Circle"))
         item.SetBitmap(CIRCLE_BMP)
 
-        SQUARE_BMP = wx.Bitmap("../icons/brush_square.jpg", wx.BITMAP_TYPE_JPEG)
+        SQUARE_BMP = wx.Bitmap(os.path.join(const.ICON_DIR, "brush_square.jpg"), wx.BITMAP_TYPE_JPEG)
         item2 = wx.MenuItem(menu, MENU_BRUSH_SQUARE, _("Square"))
         item2.SetBitmap(SQUARE_BMP)
 
@@ -770,8 +786,8 @@ class EditionTools(wx.Panel):
                                      (thresh_min, thresh_max))
 
     def OnMenu(self, evt):
-        SQUARE_BMP = wx.Bitmap("../icons/brush_square.jpg", wx.BITMAP_TYPE_JPEG)
-        CIRCLE_BMP = wx.Bitmap("../icons/brush_circle.jpg", wx.BITMAP_TYPE_JPEG)
+        SQUARE_BMP = wx.Bitmap(os.path.join(const.ICON_DIR, "brush_square.jpg"), wx.BITMAP_TYPE_JPEG)
+        CIRCLE_BMP = wx.Bitmap(os.path.join(const.ICON_DIR, "brush_circle.jpg"), wx.BITMAP_TYPE_JPEG)
 
         brush = {MENU_BRUSH_CIRCLE: const.BRUSH_CIRCLE,
                  MENU_BRUSH_SQUARE: const.BRUSH_SQUARE}
@@ -814,11 +830,11 @@ class WatershedTool(EditionTools):
         ## LINE 2
         menu = wx.Menu()
 
-        CIRCLE_BMP = wx.Bitmap("../icons/brush_circle.jpg", wx.BITMAP_TYPE_JPEG)
+        CIRCLE_BMP = wx.Bitmap(os.path.join(const.ICON_DIR, "brush_circle.jpg"), wx.BITMAP_TYPE_JPEG)
         item = wx.MenuItem(menu, MENU_BRUSH_CIRCLE, _("Circle"))
         item.SetBitmap(CIRCLE_BMP)
 
-        SQUARE_BMP = wx.Bitmap("../icons/brush_square.jpg", wx.BITMAP_TYPE_JPEG)
+        SQUARE_BMP = wx.Bitmap(os.path.join(const.ICON_DIR, "brush_square.jpg"), wx.BITMAP_TYPE_JPEG)
         item2 = wx.MenuItem(menu, MENU_BRUSH_SQUARE, _("Square"))
         item2.SetBitmap(SQUARE_BMP)
 
@@ -873,7 +889,7 @@ class WatershedTool(EditionTools):
         self.ww_wl_cbox = ww_wl_cbox
 
         # Line 6
-        bmp = wx.Bitmap("../icons/configuration.png", wx.BITMAP_TYPE_PNG)
+        bmp = wx.Bitmap(os.path.join(const.ICON_DIR, "configuration.png"), wx.BITMAP_TYPE_PNG)
         self.btn_wconfig = wx.BitmapButton(self, -1, bitmap=bmp,
                                            size=(bmp.GetWidth()+10, bmp.GetHeight()+10))
         self.btn_exp_watershed = wx.Button(self, -1, _('Expand watershed to 3D'))
@@ -941,8 +957,8 @@ class WatershedTool(EditionTools):
         self.gradient_thresh.SetMaxValue(thresh_max)
 
     def OnMenu(self, evt):
-        SQUARE_BMP = wx.Bitmap("../icons/brush_square.jpg", wx.BITMAP_TYPE_JPEG)
-        CIRCLE_BMP = wx.Bitmap("../icons/brush_circle.jpg", wx.BITMAP_TYPE_JPEG)
+        SQUARE_BMP = wx.Bitmap(os.path.join(const.ICON_DIR, "brush_square.jpg"), wx.BITMAP_TYPE_JPEG)
+        CIRCLE_BMP = wx.Bitmap(os.path.join(const.ICON_DIR, "brush_circle.jpg"), wx.BITMAP_TYPE_JPEG)
 
         brush = {MENU_BRUSH_CIRCLE: const.BRUSH_CIRCLE,
                  MENU_BRUSH_SQUARE: const.BRUSH_SQUARE}
@@ -977,7 +993,7 @@ class WatershedTool(EditionTools):
         Publisher.sendMessage('Set use ww wl', value)
 
     def OnConfig(self, evt):
-        from data.styles import WatershedConfig
+        from invesalius.data.styles import WatershedConfig
         config = WatershedConfig()
         dlg.WatershedOptionsDialog(config).Show()
 
