@@ -29,11 +29,10 @@ except(ImportError):
 import wx
 from wx.lib.pubsub import pub as Publisher
 
-import constants as const
-import data.slice_ as sl
-import presets
-
-from gui.dialogs import ClutImagedataDialog
+import invesalius.constants as const
+import invesalius.data.slice_ as sl
+import invesalius.presets as presets
+from invesalius.gui.dialogs import ClutImagedataDialog
 
 PROJECTIONS_ID = OrderedDict(((_('Normal'), const.PROJECTION_NORMAL),
                               (_('MaxIP'), const.PROJECTION_MaxIP),
