@@ -29,17 +29,24 @@ import vtkgdcm
 import gdcm
 from wx.lib.pubsub import pub as Publisher
 
-import constants as const
-import dicom
-import dicom_grouper
-import session
-
+import invesalius.constants as const
+import invesalius.reader.dicom as dicom
+import invesalius.reader.dicom_grouper as dicom_grouper
+import invesalius.session as session
 import glob
-import utils
-
+import invesalius.utils as utils
 
 import plistlib
 
+if sys.platform == 'win32':
+    try:
+        import win32api
+        _has_win32api = True
+    except ImportError:
+        _has_win32api = False
+else:
+    _has_win32api = False
+
 def ReadDicomGroup(dir_):
 
     patient_group = GetDicomGroups(dir_)
@@ -71,7 +78,7 @@ def SortFiles(filelist, dicom):
     # Sort slices
     # FIXME: Coronal Crash. necessary verify
     if (dicom.image.orientation_label <> "CORONAL"):
-        #Organize reversed image
+        ##Organize reversed image
         sorter = gdcm.IPPSorter()
         sorter.SetComputeZSpacing(True)
         sorter.SetZSpacingTolerance(1e-10)
@@ -90,18 +97,18 @@ class LoadDicom:
     
     def __init__(self, grouper, filepath):
         self.grouper = grouper
-        if sys.platform == 'win32':
-            self.filepath = filepath.encode(utils.get_system_encoding())
-        else:
-            self.filepath = filepath
+        self.filepath = filepath
         
         self.run()
     
     def run(self):
-
         grouper = self.grouper
         reader = gdcm.ImageReader()
-        reader.SetFileName(self.filepath)
+        if _has_win32api:
+            reader.SetFileName(win32api.GetShortPathName(self.filepath).encode(const.FS_ENCODE))
+        else:
+            reader.SetFileName(self.filepath)
+
         if (reader.Read()):
             file = reader.GetFile()
              
@@ -182,7 +189,12 @@ class LoadDicom:
 
             # -------------- To Create DICOM Thumbnail -----------
             rvtk = vtkgdcm.vtkGDCMImageReader()
-            rvtk.SetFileName(self.filepath)
+
+            if _has_win32api:
+                print 'dicom', win32api.GetShortPathName(self.filepath)
+                rvtk.SetFileName(win32api.GetShortPathName(self.filepath).encode(const.FS_ENCODE))
+            else:
+                rvtk.SetFileName(self.filepath)
             rvtk.Update()
             
             try:
@@ -190,7 +202,7 @@ class LoadDicom:
                 level = [float(value) for value in data.split('\\')][0]
                 data = data_dict[str(0x028)][str(0x1051)]
                 window =  [float(value) for value in data.split('\\')][0]
-            except(KeyError):
+            except(KeyError, ValueError):
                 level = 300.0
                 window = 2000.0 
      
@@ -343,7 +355,7 @@ class ProgressDicomReader:
     def GetDicomGroups(self, path, recursive):
 
         if not const.VTK_WARNING:
-            log_path = os.path.join(const.LOG_FOLDER, 'vtkoutput.txt')
+            log_path = os.path.join(const.USER_LOG_DIR, 'vtkoutput.txt').encode(const.FS_ENCODE)
             fow = vtk.vtkFileOutputWindow()
             fow.SetFileName(log_path)
             ow = vtk.vtkOutputWindow()
